### R code from vignette source 'ex32.Rnw'

###################################################
### code chunk number 1: ex32.Rnw:19-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex32.Rnw:30-33
###################################################
require(lattice)
require(sp)
require(gstat)


###################################################
### code chunk number 3: ex32.Rnw:47-48 (eval = FALSE)
###################################################
## load("Jura.RData")


###################################################
### code chunk number 4: ex32.Rnw:52-53
###################################################
load("/Users/rossiter/data/edu/dgeostats/ov/graph/jura.RData")


###################################################
### code chunk number 5: ex32.Rnw:74-76
###################################################
jura.cal <- jura.all[1:259,]
jura.val <- jura.all[260:359,]


###################################################
### code chunk number 6: ex32.Rnw:83-88
###################################################
plot(coordinates(jura.cal), col="blue", asp=1, pch=20,
xlab="UTM E", ylab="UTM N", main="Jura soil samples",
sub="Calibration: blue; Evaluation: red")
points(coordinates(jura.val), col="red", pch=1, cex=1.2)
grid(lty=1, col="black")


###################################################
### code chunk number 7: ex32.Rnw:112-116
###################################################
dim(jura.all@data)
dim(jura.all@data)[1]
valid.id <- sample(1:dim(jura.all@data)[1], 100)
sort(valid.id)


###################################################
### code chunk number 8: ex32.Rnw:125-127
###################################################
jura.val.rand <- jura.all[valid.id,]
str(jura.val.rand)


###################################################
### code chunk number 9: ex32.Rnw:136-138
###################################################
jura.cal.rand <- jura.all[!is.element(1:dim(jura.all@data)[1], valid.id),]
str(jura.cal.rand)


###################################################
### code chunk number 10: ex32.Rnw:147-151
###################################################
plot.bbox <- function(sp.object, colour="black", line.type=2) {
  b <- bbox(sp.object)
  lines(c(b["X","min"],b["X","max"],b["X","max"],b["X","min"],b["X","min"]), c(b["Y","min"],b["Y","min"],b["Y","max"],b["Y","max"],b["Y","min"]), col=colour, lty=line.type)
}


###################################################
### code chunk number 11: ex32.Rnw:156-165
###################################################
bbox(jura.val.rand)
bbox(jura.cal.rand)
plot(coordinates(jura.cal.rand), col="black", asp=1, pch=20,
xlab="UTM E", ylab="UTM N", main="Jura soil samples",
sub="Calibration: blue; Evaluation: red (random selection)")
points(coordinates(jura.val.rand), col="green", pch=1, cex=1.2)
grid(lty=1, col="black")
plot.bbox(jura.cal.rand)
plot.bbox(jura.val.rand, colour="green")


###################################################
### code chunk number 12: ex32.Rnw:174-175
###################################################
rm(valid.id, jura.cal.rand, jura.val.rand, plot.bbox)


###################################################
### code chunk number 13: ex32.Rnw:210-212
###################################################
hist(jura.cal$Co, breaks=0:20, main="Jura calibration data set", xlab="Co, mg kg-1", col="lightblue")
rug(jura.cal$Co)


###################################################
### code chunk number 14: ex32.Rnw:232-234
###################################################
v <- variogram(Co ~ 1, loc=jura.cal)
print(plot(v, plot.numbers=T, pch=20, col="darkblue"))


###################################################
### code chunk number 15: ex32.Rnw:262-264
###################################################
v <- variogram(Co ~ 1, loc=jura.cal, cutoff=1.6)
plot(v, plot.numbers=T, pch=20, col="darkblue")


###################################################
### code chunk number 16: ex32.Rnw:268-269
###################################################
print(show.vgms())


###################################################
### code chunk number 17: ex32.Rnw:275-276
###################################################
vgm()


###################################################
### code chunk number 18: ex32.Rnw:302-303
###################################################
print(show.vgms(models= c("Sph","Cir","Pen"), sill=12.5, nugget=1.5, range=1.2, max=1.6))


###################################################
### code chunk number 19: ex32.Rnw:321-324
###################################################
vm <- vgm(12.5, "Pen", 1.2, 1.5)
print(vm)
class(vm)


###################################################
### code chunk number 20: ex32.Rnw:328-329
###################################################
print(plot(v, plot.numbers=T, pch=20, col="darkblue", model=vm))


###################################################
### code chunk number 21: ex32.Rnw:355-361
###################################################
vmf <- fit.variogram(v, vm)
print(vm)
print(vmf)
vmf$range - vm$range
vmf$psill - vm$psill
sum(vmf$psill) - sum(vm$psill)


###################################################
### code chunk number 22: ex32.Rnw:379-380
###################################################
print(plot(v, plot.numbers=T, pch=20, col="darkblue", model=vmf))


###################################################
### code chunk number 23: ex32.Rnw:396-397
###################################################
1-vmf$psill[1]/sum(vmf$psill)


###################################################
### code chunk number 24: ex32.Rnw:411-420
###################################################
plot(v$gamma ~ v$dist,
     xlim=c(0, max(v$dist)*1.05), ylim=c(0, max(v$gamma)*1.2),
     pch=20, col="blue", cex=1.2,
     xlab="Separation distance", ylab="Semivariance",
     main="Variogram models",
     sub="Red: estimated; Green: fitted")
text(v$dist, v$gamma, v$np, pos=4)
lines(variogramLine(vm, maxdist=max(v$dist)), col="red", lty=2)
lines(variogramLine(vmf, maxdist=max(v$dist)), col="green")


###################################################
### code chunk number 25: ex32.Rnw:433-450
###################################################
plot(v$gamma ~ v$dist,
     xlim=c(0, max(v$dist)*1.05), ylim=c(0, max(v$gamma)*1.2),
     pch=20, col="blue", cex=1.2,
     xlab="Separation distance", ylab="Semivariance",
     main="Variogram model forms",
     sub="Fitted to Jura Cobalt")
text(v$dist, v$gamma, v$np, pos=4)
lines(variogramLine(fit.variogram(v, vgm(12.5, "Cir", 1.2, 1.5)), maxdist=max(v$dist)), col="red")
lines(variogramLine(fit.variogram(v, vgm(12.5, "Sph", 1.2, 1.5)), maxdist=max(v$dist)), col="green")
lines(variogramLine(fit.variogram(v, vgm(12.5, "Pen", 1.2, 1.5)), maxdist=max(v$dist)), col="blue")
lines(variogramLine(fit.variogram(v, vgm(12.5, "Exp", 1.2/3, 1.5)), maxdist=max(v$dist)), col="magenta")
lines(variogramLine(fit.variogram(v, vgm(12.5, "Gau", 1.2/sqrt(3), 1.5)), maxdist=max(v$dist)), col="brown")
text(1, 5, col="red", "Circular", pos=4)
text(1, 4, col="green", "Spherical", pos=4)
text(1, 3, col="blue", "Pentaspherical", pos=4)
text(1, 2, col="magenta", "Exponential", pos=4)
text(1, 1, col="brown", "Gaussian", pos=4)


###################################################
### code chunk number 26: ex32.Rnw:472-473
###################################################
str(attributes(vmf))


###################################################
### code chunk number 27: ex32.Rnw:478-479
###################################################
attributes(vmf)$SSErr


###################################################
### code chunk number 28: ex32.Rnw:487-494
###################################################
v2 <- variogram(Co ~ 1, loc=jura.cal, cutoff=1)
vmf2 <- fit.variogram(v2, vmf)
print(vmf)
print(vmf2)
attributes(vmf)$SSErr
attributes(vmf2)$SSErr
print(plot(v2, plot.numbers=T, pch=20, col="darkgreen", model=vmf2))


###################################################
### code chunk number 29: ex32.Rnw:500-515
###################################################
plot(v2$gamma ~ v2$dist,
     xlim=c(0, max(v2$dist)*1.05), ylim=c(0, max(v2$gamma)*1.2),
     pch=20, col="blue", cex=1.2,
     xlab="Separation distance", ylab="Semivariance",
     main="Fiited variogram models",
     sub="Fitted to Jura Cobalt")
text(v2$dist, v2$gamma, v2$np, pos=4)
lines(variogramLine(vmf, maxdist=1), col="red")
lines(variogramLine(vmf2, maxdist=1), col="green")
text(1, 5, col="red", "medium-range fit", pos=2)
text(1, 4, col="green", "short-range fit", pos=2)
abline(h=vmf$psill[1], col="red", lty=2)
abline(h=sum(vmf$psill), col="red", lty=2)
abline(h=vmf2$psill[1], col="green", lty=2)
abline(h=sum(vmf2$psill), col="green", lty=2)


###################################################
### code chunk number 30: ex32.Rnw:529-530
###################################################
rm(v2, vmf2)


###################################################
### code chunk number 31: ex32.Rnw:535-540
###################################################
attributes(fit.variogram(v, vgm(12.5, "Pen", 1.2, 1.5)))$SSErr
attributes(fit.variogram(v, vgm(12.5, "Cir", 1.2, 1.5)))$SSErr
attributes(fit.variogram(v, vgm(12.5, "Sph", 1.2, 1.5)))$SSErr
attributes(fit.variogram(v, vgm(12.5, "Exp", 1.2/3, 1.5)))$SSErr
attributes(fit.variogram(v, vgm(12.5, "Gau", 1.2/sqrt(3), 1.5)))$SSErr


###################################################
### code chunk number 32: ex32.Rnw:555-556
###################################################
rm(v, vm, vmf)


###################################################
### code chunk number 33: ex32.Rnw:572-577 (eval = FALSE)
###################################################
## h1 <- histogram(jura.cal$Pb, col="lavender")
## h2 <- histogram(log10(jura.cal$Pb), col="wheat")
## plot(h1, split=c(1,1,2,1), more=T)
## plot(h2, split=c(2,1,2,1), more=F)
## rm(h1, h2)


###################################################
### code chunk number 34: ex32.Rnw:581-586
###################################################
h1 <- histogram(jura.cal$Pb, col="lavender")
h2 <- histogram(log10(jura.cal$Pb), col="wheat")
print(plot(h1, split=c(1,1,2,1), more=T))
print(plot(h2, split=c(2,1,2,1), more=F))
rm(h1, h2)


###################################################
### code chunk number 35: ex32.Rnw:599-601 (eval = FALSE)
###################################################
## v <- variogram(log10(Pb) ~ 1, loc=jura.cal, cutoff=3)
## plot(v, plot.numbers=T, pch=20, col="darkblue")


###################################################
### code chunk number 36: ex32.Rnw:604-606
###################################################
v <- variogram(log10(Pb) ~ 1, loc=jura.cal, cutoff=3)
print(plot(v, plot.numbers=T, pch=20, col="darkblue"))


###################################################
### code chunk number 37: ex32.Rnw:622-624
###################################################
(vm <- vgm(0.025, "Sph", 0.4, 0.01))
(vmf <- fit.variogram(v, vm))


###################################################
### code chunk number 38: ex32.Rnw:629-634 (eval = FALSE)
###################################################
## p1 <- plot(v, model=vm, pl=T, main="log10(Pb), estimated model")
## p2 <- plot(v, model=vmf, pl=T, main="log10(Pb), fitted model")
## plot(p1, split=c(1,1,2,1), more=T)
## plot(p2, split=c(2,1,2,1), more=F)
## rm(p1, p2)


###################################################
### code chunk number 39: ex32.Rnw:638-643
###################################################
p1 <- plot(v, model=vm, pl=T, main="log10(Pb), estimated model")
p2 <- plot(v, model=vmf, pl=T, main="log10(Pb), fitted model")
print(plot(p1, split=c(1,1,2,1), more=T))
print(plot(p2, split=c(2,1,2,1), more=F))
rm(p1, p2)


###################################################
### code chunk number 40: ex32.Rnw:663-665
###################################################
(vm <- vgm(0.003, "Sph", 2.5, add.to=vmf))
(vmf2 <- fit.variogram(v, vm))


###################################################
### code chunk number 41: ex32.Rnw:671-676
###################################################
p1 <- plot(v, model=vm, pl=T, main="log10(Pb), estimated model")
p2 <- plot(v, model=vmf2, pl=T, main="log10(Pb), fitted model")
print(plot(p1, split=c(1,1,2,1), more=T))
print(plot(p2, split=c(2,1,2,1), more=F))
rm(p1, p2)


###################################################
### code chunk number 42: ex32.Rnw:688-691
###################################################
paste("Nugget:", round(100*vmf2$psill[1]/sum(vmf2$psill),0), "%")
paste("Short range:", round(100*vmf2$psill[2]/sum(vmf2$psill),0), "%")
paste("Long range:", round(100*vmf2$psill[3]/sum(vmf2$psill),0), "%")


###################################################
### code chunk number 43: ex32.Rnw:699-700
###################################################
rm(v, vm, vmf, vmf2)


###################################################
### code chunk number 44: ex32.Rnw:727-729
###################################################
data(meuse)
coordinates(meuse) <- ~ x +y


###################################################
### code chunk number 45: ex32.Rnw:736-741
###################################################
v.a <- variogram(log(zinc)~1, meuse, alpha=c(30,120), cutoff=1600)
print(plot(v.a,
           main="Directional Variograms, Meuse River, log(Zn)",
           sub="Azimuth 30N (left), 120N (right)",
           pl=T, pch=20, col="blue"))


###################################################
### code chunk number 46: ex32.Rnw:779-788
###################################################
(vmf.a <- 
 fit.variogram(v.a,
               vgm(0.55, "Sph", 1100, 0.05, anis=c(30, 0.5))))
attributes(vmf.a)$SSErr
print(plot(v.a,
    main="Fitted Anisotropic Variogram Model, Meuse River, log(Zn)",
    model=vmf.a,
    sub="Azimuth 30N (left), 120N (right)",
    pl=T, pch=20, col="blue"))


###################################################
### code chunk number 47: ex32.Rnw:800-806
###################################################
v <- variogram(log(zinc)~1, meuse, cutoff=1600)
(vmf <- fit.variogram(v, vgm(0.55, "Sph", 1100, 0.05)))
attributes(vmf)$SSErr
print(plot(v,
    main="Fitted Isotropic Variogram Model, Meuse River, log(Zn)",
    model=vmf, pl=T, pch=20, col="blue"))


###################################################
### code chunk number 48: ex32.Rnw:821-822
###################################################
rm(v.a, vmf.a, v, vmf, meuse)


###################################################
### code chunk number 49: ex32.Rnw:854-858
###################################################
jura.cal.sub <- vector("list", 4)
for (i in 1:4) {
    jura.cal.sub[[i]] <-
    jura.cal[sample(1:dim(jura.cal@data)[1], 160),] }


###################################################
### code chunk number 50: ex32.Rnw:865-869
###################################################
v.sub <- vector("list", 4)
for (i in 1:4) {
    v.sub[[i]] <-
    variogram(Co ~ 1, loc=jura.cal.sub[[i]]) }


###################################################
### code chunk number 51: ex32.Rnw:883-893
###################################################
plot(v.sub[[1]]$gamma ~ v.sub[[1]]$dist,
     xlim=c(0, max(v.sub[[1]]$dist)*1.05), ylim=c(0, max(v.sub[[1]]$gamma)*1.2),
     col=1, cex=1.2,
     xlab="Separation distance", ylab="Semivariance",
     main="Empirical variograms from subsamples",
     type="b")
for (i in 2:4) {
     points(v.sub[[i]]$gamma ~ v.sub[[i]]$dist, col=i, cex=1.2, type="b")
   }



###################################################
### code chunk number 52: ex32.Rnw:906-910
###################################################
vmf.sub <- vector("list", 4)
for (i in 1:4) {
  vmf.sub[[i]] <- fit.variogram(v.sub[[i]], vgm(12.5, "Pen", 1.2, 1.5)) }
print(vmf.sub)


###################################################
### code chunk number 53: ex32.Rnw:918-930
###################################################
xlim.max <- max(v.sub[[1]]$dist)*1.05
plot(v.sub[[1]]$gamma ~ v.sub[[1]]$dist,
     xlim=c(0, xlim.max), ylim=c(0, max(v.sub[[1]]$gamma)*1.2),
     col=1, cex=1.2,
     xlab="Separation distance", ylab="Semivariance",
     main="Fitted variograms from subsamples")
for (i in 2:4) {
     points(v.sub[[i]]$gamma ~ v.sub[[i]]$dist,
     col=i, cex=1.2) }
for (i in 1:4) {
    lines(variogramLine(vmf.sub[[i]], maxdist=xlim.max), col=i) }
rm(xlim.max)


###################################################
### code chunk number 54: ex32.Rnw:939-952
###################################################
nuggets <- NULL; psills <- NULL; ranges <- NULL
for (i in 1:4) {
  nuggets <- c(nuggets, vmf.sub[[i]]$psill[1]);
  psills <- c(psills, vmf.sub[[i]]$psill[2]);
  ranges <- c(ranges, vmf.sub[[i]]$range[2])
}
print(sort(nuggets))
diff(range(nuggets))/median(nuggets)
print(sort(psills))
diff(range(psills))/median(psills)
print(sort(ranges))
diff(range(ranges))/median(ranges)
rm(nuggets, psills, ranges)


###################################################
### code chunk number 55: ex32.Rnw:967-968
###################################################
rm(jura.cal.sub, v.sub, vmf.sub, i)


