### R code from vignette source 'ex33.Rnw'

###################################################
### code chunk number 1: ex33.Rnw:19-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex33.Rnw:27-28
###################################################
require(lattice)


###################################################
### code chunk number 3: ex33.Rnw:100-107
###################################################
require(MASS)
require(spatial)
data(topo)
str(topo)
summary(topo)
# while (is.element("topo", search())) detach(topo)
# attach(topo)


###################################################
### code chunk number 4: ex33.Rnw:110-116 (eval = FALSE)
###################################################
## require(spatial)
## require(MASS)
## help(topo)
## str(topo)
## summary(topo)
## # attach(topo)


###################################################
### code chunk number 5: ex33.Rnw:134-139
###################################################
with(topo, {
  plot(y ~ x, cex=3*z/max(z), pch=1, col="blue", asp=1,
       main="Elevation (feet)", xlab="E", ylab="N");
     text(x, y, z, pos=2) } )
grid(lty=1)


###################################################
### code chunk number 6: ex33.Rnw:156-160
###################################################
ts2 <- surf.ls(2, topo$x, topo$y, topo$z)
class(ts2)
summary(ts2)
ts2$beta


###################################################
### code chunk number 7: ex33.Rnw:171-173
###################################################
tmat2 <- trmat(ts2, 0, 6.5, 0, 6.5, n=50)
str(tmat2)


###################################################
### code chunk number 8: ex33.Rnw:180-185
###################################################
eqscplot(tmat2, type="n",
     main="OLS 2nd-order trend surface", sub="elevation (feet)", xlab="E", ylab="N")
contour(tmat2, add=T, lty=1, col="blue")
grid(lty=1)
points(topo$x, topo$y, cex=3*(topo$z/max(topo$z)), pch=23, bg=3)


###################################################
### code chunk number 9: ex33.Rnw:204-211
###################################################
eqscplot(tmat2, type="n",
     main="OLS 2nd-order trend surface", sub="elevation (feet)", xlab="E", ylab="N")
contour(tmat2, add=T, lty=1, col="blue")
grid(lty=1)
r <- residuals(ts2)
points(topo$x, topo$y, cex=3*abs(r)/max(abs(r)), pch=23, bg=ifelse(r < 0, "red", "green"))
rm(r)


###################################################
### code chunk number 10: ex33.Rnw:220-221
###################################################
plot(ts2)


###################################################
### code chunk number 11: ex33.Rnw:226-228
###################################################
infl.ts2 <- trls.influence(ts2)
str(infl.ts2)


###################################################
### code chunk number 12: ex33.Rnw:236-238
###################################################
(cand <- as.data.frame(infl.ts2)[abs(infl.ts2$stresid) > 1.5, ])
rm(infl.ts2)


###################################################
### code chunk number 13: ex33.Rnw:243-249
###################################################
eqscplot(tmat2, type = "n")
contour(tmat2, add = TRUE, col = "grey")
plot.trls(ts2, add = TRUE, div = 2)
cand.xy <- topo[as.integer(rownames(cand)), c("x", "y")]
points(cand.xy, pch = 16, col = "orange")
text(cand.xy, labels = rownames(cand.xy), pos = 4, offset = 0.5)


###################################################
### code chunk number 14: ex33.Rnw:252-253
###################################################
rm(cand, cand.xy)


###################################################
### code chunk number 15: ex33.Rnw:275-277
###################################################
c <- correlogram(ts2, nint=16, plotit=T)
as.data.frame(c)


###################################################
### code chunk number 16: ex33.Rnw:282-284
###################################################
plot(c, ylim=c(-.4, 1), xlim=c(0,4), col="blue", pch=20, cex=2)
abline(h=0)


###################################################
### code chunk number 17: ex33.Rnw:298-302
###################################################
plot(c, ylim=c(-.4, 1), xlim=c(0,4), col="blue", pch=20, cex=2)
abline(h=0)
d <- seq(0.1, 4, by=.1)
lines(d, expcov(d, d=.5, alpha=0.05), col="blue")


###################################################
### code chunk number 18: ex33.Rnw:319-320
###################################################
ts2.g<-surf.gls(2, expcov, d=0.5, alpha=0.05, topo$x, topo$y, topo$z)


###################################################
### code chunk number 19: ex33.Rnw:327-329
###################################################
summary(ts2.g)
summary(ts2)


###################################################
### code chunk number 20: ex33.Rnw:336-339
###################################################
ts2.g$beta
ts2$beta
100*(ts2.g$beta - ts2$beta)/ts2$beta


###################################################
### code chunk number 21: ex33.Rnw:346-348
###################################################
summary(residuals(ts2.g))
summary(residuals(ts2))


###################################################
### code chunk number 22: ex33.Rnw:355-363
###################################################
tmat2.g <- trmat(ts2.g, 0, 6.5, 0, 6.5, n=50)
eqscplot(ts2, type="n",
     main="OLS and GLS trend surfaces", xlab="E", ylab="N", sub="Black: GLS; Blue: OLS")
contour(tmat2.g, level=seq(720, 960, 20), add=T)
contour(tmat2, level=seq(720, 960, 20), add=T, lty=2, col="blue")
grid(lty=1)
points(topo$x, topo$y, cex=topo$z*2.5/max(topo$z), pch=23, bg=3)
text(topo$x, topo$y, topo$z, pos=2)


###################################################
### code chunk number 23: ex33.Rnw:379-395
###################################################
par(mfrow=c(1,2))
r <- residuals(ts2)
r.g <- residuals(ts2.g)
r.max <- max(abs(r), abs(r.g))
eqscplot(tmat2.g, type="n",
     main="GLS 2nd-order trend surface", sub="elevation (feet)", xlab="E", ylab="N")
contour(tmat2.g, add=T, lty=1, col="blue")
grid(lty=1)
points(topo$x, topo$y, cex=3*abs(r.g)/r.max, pch=23, bg=ifelse(r < 0, "red", "green"))
eqscplot(tmat2, type="n",
     main="OLS 2nd-order trend surface", sub="elevation (feet)", xlab="E", ylab="N")
contour(tmat2, add=T, lty=1, col="blue")
grid(lty=1)
points(topo$x, topo$y, cex=3*abs(r)/r.max, pch=23, bg=ifelse(r < 0, "red", "green"))
rm(r, r.g, r.max)
par(mfrow=c(1,1))


###################################################
### code chunk number 24: ex33.Rnw:411-417
###################################################
c.g <- correlogram(ts2.g, nint=16, plotit=F)
plot(c.g, ylim=c(-.4, 1), xlim=c(0,4), col="blue", pch=20, cex=2)
abline(h=0)
d <- seq(0.1, 4, by=.1)
lines(d, expcov(d, d=.5, alpha=0.05), col="blue")
rm(d)


###################################################
### code chunk number 25: ex33.Rnw:430-439
###################################################
tmp <- as.data.frame(cbind(lag = c.g$x, gls.corr = c.g$y,
                           ols.corr = c$y, diff = c.g$y-c$y))
plot(diff ~ lag, data=tmp, ylim=c(-.2, 1), pch=1,
     main="Spatial correlation",
     sub="GLS: blue; OLS: red; difference: black")
points(tmp$lag, tmp$gls.corr, col="blue", pch=20, cex=2)
points(tmp$lag, tmp$ols.corr, col="red", pch=20, cex=2)
abline(h=0)
rm(tmp)


###################################################
### code chunk number 26: ex33.Rnw:459-462
###################################################
# detach(topo)
rm(topo, ts2, ts2.g, tmat2, tmat2.g, c, c.g)
detach(package:spatial)


