### R code from vignette source 'ex43.Rnw'

###################################################
### code chunk number 1: load-meuse
###################################################
require(sp)
data(meuse)
coordinates(meuse) <- ~ x +y


###################################################
### code chunk number 2: comp-vgm-a
###################################################
require(gstat)
v.a <- variogram(log(zinc)~1, meuse, alpha=c(30,120), cutoff=1600)
print(plot(v.a,
           main="Directional Variograms, Meuse River, log(Zn)",
           sub="Azimuth 30N (left), 120N (right)",
           pl=T, pch=20, col="blue"))


###################################################
### code chunk number 3: fit-vgm-a
###################################################
(vmf.a <- 
 fit.variogram(v.a,
               vgm(psill=0.55, model="Sph", range=1100,
                   nugget=0.05, anis=c(30, 0.5))))
print(plot(v.a,
    main="Fitted Anisotropic Variogram Model, Meuse River, log(Zn)",
    model=vmf.a,
    sub="Azimuth 30N (left), 120N (right)",
    pl=T, pch=20, col="blue"))


###################################################
### code chunk number 4: fit-vgm-o
###################################################
v <- variogram(log(zinc)~1, meuse, cutoff=1600)
(vmf <- fit.variogram(v, vgm(0.55, "Sph", 1100, 0.05)))
attributes(vmf)$SSErr
print(plot(v,
    main="Fitted Isotropic Variogram Model, Meuse River, log(Zn)",
    model=vmf, pl=T, pch=20, col="blue"))


###################################################
### code chunk number 5: predict-ok
###################################################
data(meuse.grid)
coordinates(meuse.grid) <- ~ x + y
gridded(meuse.grid) <- TRUE
k <- krige(log(zinc) ~ 1, loc=meuse, newdata=meuse.grid, model=vmf)
k.a <- krige(log(zinc) ~ 1, loc=meuse, newdata=meuse.grid, model=vmf.a)
summary(k.a$var1.pred - k$var1.pred)
summary(k.a$var1.var - k$var1.var)


###################################################
### code chunk number 6: compute-display-ok
###################################################
p.at <- seq(round(min(k$var1.pred, k.a$var1.pred),1)-0.1,
            round(max(k$var1.pred, k$var1.pred.a)+0.1, 1),
            by=0.1)
p1 <- spplot(k, zcol="var1.pred",
             col.regions=bpy.colors(length(p.at)),
             key.space="right", at=p.at,
             main="Predicted values, Zn log(ppm)",
             sub="Isotropic variogram model", xlab="E", ylab="N",
             scales=list(draw=T))
p2 <- spplot(k.a, zcol="var1.pred",
             col.regions=bpy.colors(length(p.at)),
             key.space="right", at=p.at,
             main="Predicted values, Zn log(ppm)",
             sub="Anisotropic variogram model", xlab="E", ylab="N",
             scales=list(draw=T))



###################################################
### code chunk number 7: display-ok
###################################################
print(p1, split=c(1,1,2,1), more=T)
print(p2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 8: predict-diff
###################################################
data(meuse.riv)
meuse.riv.poly <- SpatialPolygons(
    list(Polygons(list(Polygon(meuse.riv)),
                  "meuse.riv"))) 
k.a$var1.diff <- k.a$var1.pred - k$var1.pred
sp.pts <- list("sp.points", meuse, pch=1,
               cex=2*log(meuse$zinc)/max(log(meuse$zinc)))
sp.riv <- list("sp.polygons", meuse.riv.poly)
spplot(k.a, zcol="var1.diff", col.regions=heat.colors(64),
       main="OK predictions, Aniso - Iso", sub="log(ppm Zn)",
       sp.layout=list(sp.pts, sp.riv))


###################################################
### code chunk number 9: display-ok-var-compute
###################################################
p.at <- seq(round(min(k$var1.var, k.a$var1.var),1)-0.1,
            round(max(k$var1.var, k$var1.var.a)+0.1, 1),
            by=0.01)
p1 <- spplot(k, zcol="var1.var",
             col.regions=topo.colors(length(p.at)),
             key.space="right", at=p.at,
             main="Prediction variances, Zn log(ppm)^2",
             sub="Isotropic variogram model",
             xlab="E", ylab="N", scales=list(draw=T))
p2 <- spplot(k.a, zcol="var1.var",
             col.regions=topo.colors(length(p.at)),
             key.space="right", at=p.at,
             main="Prediction variances, Zn log(ppm)^2",
             sub="Anisotropic variogram model",
             xlab="E", ylab="N", scales=list(draw=T))
print(p1, split=c(1,1,2,1), more=T)
print(p2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 10: display-ok-var
###################################################
print(p1, split=c(1,1,2,1), more=T)
print(p2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 11: predict-diff-var
###################################################
k.a$var1.diff.v <- k.a$var1.var - k$var1.var
sp.pts <- list("sp.points", meuse, pch=20)
spplot(k.a, zcol="var1.diff.v", col.regions=cm.colors(64),
       main="OK prediction variances, Aniso - Iso",
       sub="log(ppm Zn)^2",
       sp.layout=list(sp.pts, sp.riv))


###################################################
### code chunk number 12: rm-meuse (eval = FALSE)
###################################################
## rm(v, vmf, vmf.a, k, k.a, p.at, sp.pts, sp.riv,
##    meuse.riv, meuse.riv.poly, p1, p2)


###################################################
### code chunk number 13: fit-zonal-aniso
###################################################
vm.major <- vgm(0.52, "Sph", 1100, 0.05, anis=c(30, 0.9))
plot(v.a, vm.major, pl=T, pch=20, col="blue")


###################################################
### code chunk number 14: fit-zonal-aniso-2
###################################################
(vm.zonal <- vgm(0.45, "Sph", 1000*10000, anis=c(30,.0001), add.to = vm.major))
plot(v.a, vm.zonal, pl=T, pch=20, col="blue")


###################################################
### code chunk number 15: krige-zonal-aniso-x
###################################################
k.z <- krige(log(zinc) ~ 1, loc=meuse,
             newdata=meuse.grid, model=vm.zonal)
p1 <- spplot(k.z, zcol="var1.pred",
             col.regions=bpy.colors(64),
             main="OK predictions, zonal model",
             sub="log ppm(Zn)")
p2 <- spplot(k.z, zcol="var1.var",
             col.regions=topo.colors(64),
             main="OK prediction variances, zonal model",
             sub="(log ppm(Zn))^2")


###################################################
### code chunk number 16: krige-zonal-aniso
###################################################
print(p1, split=c(1,1,2,1), more=T)
print(p2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 17: zonal-clean (eval = FALSE)
###################################################
## rm(k.z, vm.zonal, vm.major, v.a, meuse, meuse.grid, p1, p2)


###################################################
### code chunk number 18: ex43.Rnw:457-463 (eval = FALSE)
###################################################
## k.cv <- krige.cv(log(zinc) ~ 1, loc = meuse, model = vmf)
## k.cv.a <- krige.cv(log(zinc) ~ 1, loc = meuse, model = vmf.a)
## k.cv.zonal <- krige.cv(log(zinc) ~ 1, loc = meuse, model = vm.zonal)
## summary(k.cv$zscore)
## summary(k.cv.a$zscore)
## summary(k.cv.zonal$zscore)


###################################################
### code chunk number 19: ex43.Rnw:466-469
###################################################
rm(v, vmf, vmf.a, k, k.a, p.at, sp.pts, sp.riv,
   meuse.riv, meuse.riv.poly, p1, p2)
rm(k.z, vm.zonal, vm.major, v.a, meuse, meuse.grid)


