### R code from vignette source 'ex5a2.Rnw'

###################################################
### code chunk number 1: ex5a2.Rnw:19-23
###################################################
options(prompt="> ", continue="   ", digits=5, width=60, show.signif.stars=T)
par(mfrow=c(1,1))
# rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex5a2.Rnw:57-65
###################################################
levels(jura.cal$Land3)
levels(jura.cal$Rock4)
tmp <- cbind(by(jura.cal$Co, jura.cal$Rock4, length), by(jura.cal$Co, jura.cal$Rock4, mean), by(jura.cal$Co, jura.cal$Rock4, var))
colnames(tmp) <- c("n", "mean", "variance")
print(tmp)
tmp <- cbind(by(jura.cal$Co, jura.cal$Land3, length), by(jura.cal$Co, jura.cal$Land3, mean), by(jura.cal$Co, jura.cal$Land3, var))
colnames(tmp) <- c("n", "mean", "variance")
print(tmp)


###################################################
### code chunk number 3: ex5a2.Rnw:89-92
###################################################
print(spplot(jura50, zcol="Rock4", col.regions=topo.colors(4),
             key.space="right",
             main="Jura 50m prediction grid, Rock type"))


###################################################
### code chunk number 4: ex5a2.Rnw:121-123
###################################################
jura.cal.split <- split(as.data.frame(jura.cal), jura.cal$Rock4)
for (i in 1:4) coordinates(jura.cal.split[[i]]) <- c("X","Y")


###################################################
### code chunk number 5: ex5a2.Rnw:129-141
###################################################
v <- NULL; for (i in 1:4) {
    v[[i]] <- variogram(Co ~ 1, loc=jura.cal.split[[i]], 
                        cutoff=0.7, width=0.1) };
ylim <- c(0, max(unlist(lapply(v, function(x) max(x$gamma)))))
plot(v[[1]]$gamma ~ v[[1]]$dist, type="n", ylim=ylim,
     xlab="separation", ylab="semivariance",
     main="Empirical variogram, Co, per stratum")
for (i in 1:4) lines(v[[i]]$dist, v[[i]]$gamma, type="b", col=i)
grid()
for (i in 1:4) text(v[[i]]$dist, v[[i]]$gamma, v[[i]]$np, pos=4)
names(jura.cal$Rock4)
legend("topleft", levels(jura.cal$Rock4), pch=1, col=1:4)


###################################################
### code chunk number 6: ex5a2.Rnw:162-166
###################################################
start.model <- list(vgm(2.5, "Gau", 0.55/sqrt(3), 0.5),
                    vgm(6, "Pen", 0.35, 2),
                    vgm(6, "Pen", 0.35, 1),
                    vgm(7, "Sph", 0.35, 1))


###################################################
### code chunk number 7: ex5a2.Rnw:172-181
###################################################
p <- NULL
for (i in 1:4) {
  p[[i]] <- plot(v[[i]], plot.numbers=T, pch=20, 
                 model=start.model[[i]],
                 main=levels(jura.cal$Rock4)[i], ylim=c(0,13)) }
print(p[[1]], split=c(1,1,2,2), more=T)
print(p[[2]], split=c(2,1,2,2), more=T)
print(p[[3]], split=c(1,2,2,2), more=T)
print(p[[4]], split=c(2,2,2,2), more=F)


###################################################
### code chunk number 8: ex5a2.Rnw:187-191
###################################################
for (i in 1:4) {
  vmf[[i]] <- fit.variogram(v[[i]], start.model[[i]]);
  print(vmf[[i]])
}


###################################################
### code chunk number 9: ex5a2.Rnw:201-210
###################################################
p <- NULL
for (i in 1:4) {
  p[[i]] <- plot(v[[i]], plot.numbers=T, pch=20,
                 model=vmf[[i]], main=levels(jura.cal$Rock4)[i],
                 ylim=c(0,13)) }
print(p[[1]], split=c(1,1,2,2), more=T)
print(p[[2]], split=c(2,1,2,2), more=T)
print(p[[3]], split=c(1,2,2,2), more=T)
print(p[[4]], split=c(2,2,2,2), more=F)


###################################################
### code chunk number 10: ex5a2.Rnw:225-233
###################################################
(k <- list(NULL, NULL, NULL, NULL))
for (i in 1:4) {
k[[i]] <- krige(Co ~ 1,
                loc=jura.cal[as.numeric(jura.cal$Rock4) == i,],
                newdata=jura50[as.numeric(jura50$Rock4) == i,],
                model=vmf[[i]], nmax=36) ;
gridded(k[[i]]) <- T
}


###################################################
### code chunk number 11: ex5a2.Rnw:240-251
###################################################
zlim <-ceiling(max(unlist(lapply(k,function(x) max(x$var1.pred, na.rm=T)))));
p <- NULL; for (i in 1:4) {
pts <- jura.cal[as.numeric(jura.cal$Rock4) == i,];
layout.1 <- list("sp.points", pts,
                 pch=1, col="black", cex=2*pts$Co/max(pts$Co));
  p[[i]] <- spplot(k[[i]],
                   zcol="var1.pred", col.regions=bpy.colors(64),
                   at=seq(0,zlim,by=0.5), main=levels(jura.cal$Rock4)[i],
                   xlim=bbox(jura50)["X",], ylim=bbox(jura50)["Y",],
                   sp.layout=list(layout.1)
                   )};


###################################################
### code chunk number 12: ex5a2.Rnw:256-260
###################################################
print(p[[1]], split=c(1,1,2,2), more=T);
print(p[[2]], split=c(2,1,2,2), more=T);
print(p[[3]], split=c(1,2,2,2), more=T)
print(p[[4]], split=c(2,2,2,2), more=F)


###################################################
### code chunk number 13: ex5a2.Rnw:268-278
###################################################
zlim <- ceiling(max(unlist(lapply(k, function(x) max(x$var1.var, na.rm=T)))));
p <- NULL; for (i in 1:4) {
pts <- jura.cal[as.numeric(jura.cal$Rock4) == i,];
layout.2 <- list("sp.points", pts, pch=20, col="black", cex=0.5);
p[[i]] <- spplot(k[[i]],
                   zcol="var1.var", col.regions=topo.colors(64),
                   at=seq(0,zlim,by=0.5), main=levels(jura.cal$Rock4)[i],
                   xlim=bbox(jura50)["X",], ylim=bbox(jura50)["Y",],
                   sp.layout=list(layout.2)
                 )};


###################################################
### code chunk number 14: ex5a2.Rnw:283-287
###################################################
print(p[[1]], split=c(1,1,2,2), more=T);
print(p[[2]], split=c(2,1,2,2), more=T);
print(p[[3]], split=c(1,2,2,2), more=T)
print(p[[4]], split=c(2,2,2,2), more=F)


###################################################
### code chunk number 15: ex5a2.Rnw:299-302
###################################################
for (i in 1:4)  k[[i]] <- as(k[[i]], "SpatialPointsDataFrame")
k.st <- rbind(k[[1]], k[[2]], k[[3]], k[[4]])
gridded(k.st) <-T; fullgrid(k.st) <- T


###################################################
### code chunk number 16: ex5a2.Rnw:310-317
###################################################
plot.stk <- spplot(k.st, zcol="var1.pred",
             col.regions=bpy.colors(64),
             at=seq(0, ceiling(max(k.st$var1.pred, na.rm=T)),
                    by=0.5),
             main="StK prediction", sub="Co (ppm)"
             )
print(plot.stk)


###################################################
### code chunk number 17: ex5a2.Rnw:328-336
###################################################
plot.stk.v <- spplot(k.st, zcol="var1.var",
             col.regions=topo.colors(64),
             at=seq(0, ceiling(max(k.st$var1.var, na.rm=T)),
                    by=0.5),
             key.space="right",
             main="StK prediction variance", sub="Co (ppm^2)"
             )
print(plot.stk.v)


###################################################
### code chunk number 18: ex5a2.Rnw:349-366
###################################################
stretch <- seq(0, ceiling(max(k.50$var1.pred,
                              kr.50$var1.pred,
                              k.st$var1.pred, na.rm=T)),
                  by=1)
plot.ok <- spplot(k.50, zcol="var1.pred", at=stretch,
              col.regions=bpy.colors(64),
              main="OK predictions",
              sub="Co (ppm)")
plot.ked <- spplot(kr.50, zcol="var1.pred", at=stretch,
              col.regions=bpy.colors(64),
              main="KED predictions, Rock type covariable",
              sub="Co (ppm)")
plot.stk <- spplot(k.st, zcol="var1.pred", at=stretch,
             col.regions=bpy.colors(64),
             main="StK prediction, Rock type strata",
             sub="Co (ppm)"
             )                    


###################################################
### code chunk number 19: ex5a2.Rnw:371-374
###################################################
print(plot.ok, split=c(1,1,3,1), more=T)
print(plot.ked, split=c(2,1,3,1), more=T)
print(plot.stk, split=c(3,1,3,1), more=F)


###################################################
### code chunk number 20: ex5a2.Rnw:384-400
###################################################
stretch <- seq(0, ceiling(max(k.50$var1.var, kr.50$var1.var,
                              k.st$var1.var, na.rm=T)),
               by=1)
plot.ok.v <- spplot(k.50, zcol="var1.var", at=stretch,
              col.regions=topo.colors(64),
              main="OK variance",
              sub="Co (ppm)")
plot.ked.v <- spplot(kr.50, zcol="var1.var", at=stretch,
              col.regions=topo.colors(64),
              main="KED variance, Rock type covariable",
              sub="Co (ppm)")
plot.stk.v <- spplot(k.st, zcol="var1.var",
             col.regions=topo.colors(64), at=stretch,
             main="StK variance, Rock type strata",
             sub="Co (ppm)"
             )                    


###################################################
### code chunk number 21: ex5a2.Rnw:404-407
###################################################
print(plot.ok.v, split=c(1,1,3,1), more=T)
print(plot.ked.v, split=c(2,1,3,1), more=T)
print(plot.stk.v, split=c(3,1,3,1), more=F)


###################################################
### code chunk number 22: ex5a2.Rnw:419-421 (eval = FALSE)
###################################################
## rm(plot.ok, plot.ked, plot.ok.v, plot.ked.v, plot.stk, plot.stk.v, stretch)
## rm(k.st, k, p, v, start.model, vmf, jura.cal.split, ylim, zlim, layout.1, layout.2)


