### R code from vignette source 'ex5b1.Rnw'

###################################################
### code chunk number 1: ex5b1.Rnw:20-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex5b1.Rnw:45-48
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex5b1.Rnw:61-62 (eval = FALSE)
###################################################
## load("JuraEx4.RData")


###################################################
### code chunk number 4: ex5b1.Rnw:66-67
###################################################
load("/Users/rossiter/data/edu/dgeostats/ex/ds/jura/cooked/JuraEx4.RData")


###################################################
### code chunk number 5: ex5b1.Rnw:86-87
###################################################
str(jura.cal@data)


###################################################
### code chunk number 6: ex5b1.Rnw:97-104
###################################################
par(mfrow=c(4,2))
for (i in 3:9) {
  hist(jura.cal@data[,i], freq=FALSE, breaks=16, col="lightblue", main=names(jura.cal@data[i]), xlab="mg kg-1");
  rug(jura.cal@data[,i])
  lines(density(jura.cal@data[,i]), col="red")
  }
par(mfrow=c(1,1))


###################################################
### code chunk number 7: ex5b1.Rnw:148-156
###################################################
skew <- function(v) {
n <- length(v);
mp3 <- sum(v^3)/n;
mp2 <- sum(v^2)/n;
mu <- mean(v);
m3 <- mp3 - 3*mp2*mu + 2 * mu^3;
return(m3 / sd(v)^3)
}


###################################################
### code chunk number 8: ex5b1.Rnw:165-168
###################################################
for (i in 3:9) {
  print(paste(names(jura.cal@data[i]), ":", round(skew(jura.cal@data[,i]), 3)))
}


###################################################
### code chunk number 9: ex5b1.Rnw:182-189
###################################################
par(mfrow=c(2,2))
for (i in c(3:5,9)) {
  hist(log(jura.cal@data[,i]), freq=FALSE, breaks=16, col="lavender", main=paste("Log-", names(jura.cal@data[i]), sep=""), xlab="log(mg kg-1)");
  rug(log(jura.cal@data[,i]))
  lines(density(log(jura.cal@data[,i])), col="red")
  }
par(mfrow=c(1,1))


###################################################
### code chunk number 10: ex5b1.Rnw:196-199
###################################################
for (i in c(3:5,9)) {
  print(paste("log(",names(jura.cal@data[i]), ") : ", round(skew(log(jura.cal@data[,i])), 3), sep=""))
}


###################################################
### code chunk number 11: ex5b1.Rnw:214-218
###################################################
jura.all@data$lZn <- log(jura.all@data$Zn)
jura.cal@data$lZn <- log(jura.cal@data$Zn)
jura.val@data$lZn <- log(jura.val@data$Zn)
str(jura.cal@data)


###################################################
### code chunk number 12: ex5b1.Rnw:236-238
###################################################
v <- variogram(lZn ~ 1, jura.cal, cutoff=1.4)
print(plot(v, pl=T))


###################################################
### code chunk number 13: ex5b1.Rnw:244-247
###################################################
vm <- vgm(0.06, "Sph", 0.6, 0.01)
vm <- vgm(0.09, "Sph", 1.2, add.to=vm)
print(plot(v, pl=T, model=vm))


###################################################
### code chunk number 14: ex5b1.Rnw:250-252
###################################################
(vmf <- fit.variogram(v, vm))
print(plot(v, pl=T, model=vmf))


###################################################
### code chunk number 15: ex5b1.Rnw:266-268
###################################################
k.lZn <- krige(lZn ~ 1, jura.cal, jura.grid, model=vmf)
summary(k.lZn)


###################################################
### code chunk number 16: ex5b1.Rnw:275-280
###################################################
print(spplot(k.lZn, zcol="var1.pred", pretty=T, contour=T,
             col.regions=bpy.colors(64),
             main="Predicted values, Zn (log mg kg-1)",
             xlab="UTM E", ylab="UTM N",
             scales=list(draw=T)))


###################################################
### code chunk number 17: ex5b1.Rnw:287-292
###################################################
print(spplot(k.lZn, zcol="var1.var", pretty=T, contour=T,
             col.regions=topo.colors(64),
             main="Kriging variance, Pb ((log-mg kg-1)^2)",
             xlab="UTM E", ylab="UTM N",
             scales=list(draw=T)))


###################################################
### code chunk number 18: ex5b1.Rnw:384-385
###################################################
(g  <- gstat(NULL, id = "lZn", form = lZn ~ 1, data=jura.cal, model=vmf)) 


###################################################
### code chunk number 19: ex5b1.Rnw:392-396
###################################################
jura.one <- SpatialPoints(jura.grid[1, drop=FALSE])
k.lZn.blue <- predict.gstat(g, newdata=jura.one, BLUE=T)
k.lZn.blue$lZn.pred
k.lZn.blue$lZn.var


###################################################
### code chunk number 20: ex5b1.Rnw:407-408
###################################################
(Zn.blue <- exp(k.lZn.blue$lZn.pred + k.lZn.blue$lZn.var/2))


###################################################
### code chunk number 21: ex5b1.Rnw:415-416
###################################################
mean(jura.cal$Zn)


###################################################
### code chunk number 22: ex5b1.Rnw:425-427
###################################################
jura.cal$lZn.res <- jura.cal$lZn - k.lZn.blue$lZn.pred
summary(jura.cal$lZn.res)


###################################################
### code chunk number 23: ex5b1.Rnw:442-444
###################################################
k.lZn.res.sk <- krige(lZn.res ~ 1, jura.cal, newdata=jura.grid, model=vmf, beta=0) 
summary(k.lZn.res.sk)


###################################################
### code chunk number 24: ex5b1.Rnw:451-452
###################################################
summary(round(k.lZn.res.sk$var1.var - k.lZn$var1.var, 3))


###################################################
### code chunk number 25: ex5b1.Rnw:466-468
###################################################
k.lZn.res.sk$res.pred <- exp(k.lZn.res.sk$var1.pred + k.lZn.res.sk$var1.var/2)
summary(k.lZn.res.sk$res.pred)


###################################################
### code chunk number 26: ex5b1.Rnw:476-479
###################################################
(mu.Z <- exp(k.lZn.blue$lZn.var/2))
k.lZn.res.sk$res.var <- mu.Z^2 * exp(k.lZn.res.sk$var1.var) * ( 1 - exp( -k.lZn.res.sk$var1.var) / 2)
summary(k.lZn.res.sk$res.var)


###################################################
### code chunk number 27: ex5b1.Rnw:486-491
###################################################
print(Zn.blue)
k.lZn$Zn.pred <- Zn.blue * k.lZn.res.sk$res.pred
summary(k.lZn$Zn.pred)
k.lZn$Zn.var <- k.lZn.res.sk$res.var
summary(k.lZn$Zn.var)


###################################################
### code chunk number 28: ex5b1.Rnw:498-503
###################################################
print(spplot(k.lZn, zcol="Zn.pred", pretty=T, contour=T,
             col.regions=bpy.colors(64),
             main="Predicted values, Zn (mg kg-1)",
             xlab="UTM E", ylab="UTM N",
             scales=list(draw=T)))


###################################################
### code chunk number 29: ex5b1.Rnw:510-515
###################################################
print(spplot(k.lZn, zcol="Zn.var", pretty=T, contour=T,
             col.regions=topo.colors(64),
             main="Kriging variance, Pb ((mg kg-1)^2)",
             xlab="UTM E", ylab="UTM N",
             scales=list(draw=T)))


###################################################
### code chunk number 30: ex5b1.Rnw:525-526 (eval = FALSE)
###################################################
## rm(skew, g, i, v, vm, vmf, k.lZn, k.lZn.blue, k.lZn.res, k.lZn.res.sk, Zn.blue, mu.Z)


