### R code from vignette source 'ex63.Rnw'

###################################################
### code chunk number 1: ex63.Rnw:59-69
###################################################
min.x <- floor((bbox(jura.all)["X", "min"] - 0.1)*10)/10
max.x <- ceiling((bbox(jura.all)["X", "max"] + 0.1)*10)/10
min.y <- floor((bbox(jura.all)["Y", "min"] - 0.1)*10)/10
max.y <- ceiling((bbox(jura.all)["Y", "max"] + 0.1)*10)/10
cells.x <- (max.x - min.x)*20
cells.y <- (max.y - min.y)*20
jura.grid <- SpatialGrid(GridTopology(c(min.x+.025, min.y+.025), c(0.05, 0.05), c(cells.x, cells.y)))
gridded(jura.grid)=TRUE
fullgrid(jura.grid)=TRUE
rm(min.x, max.x, min.y, max.y, cells.x, cells.y)


###################################################
### code chunk number 2: ex63.Rnw:73-76
###################################################
if (file.exists("./ds/jura/cooked/JuraSim4.RData")) 
  { load("./ds/jura/cooked/JuraSim4.RData") } else
  { set.seed=621; k.sim.4 <- krige(Co ~ 1, loc = jura.cal, newdata = jura.grid, model=vmf, nsim=4, nmax=128) }


###################################################
### code chunk number 3: ex63.Rnw:81-83 (eval = FALSE)
###################################################
## set.seed=621;
## k.sim.4 <- krige(Co ~ 1, loc = jura.cal, newdata = jura.grid, model=vmf, nsim=4, nmax=128)


###################################################
### code chunk number 4: ex63.Rnw:88-89
###################################################
if (!file.exists("./ds/jura/cooked/JuraSim4.RData")) save(k.sim.4, file="./ds/jura/cooked/JuraSim4.RData")


###################################################
### code chunk number 5: ex63.Rnw:96-98
###################################################
summary(k.sim.4)
summary(jura.cal$Co)


###################################################
### code chunk number 6: ex63.Rnw:114-117
###################################################
class(k.sim.4)
gridded(k.sim.4) <- TRUE
class(k.sim.4)


###################################################
### code chunk number 7: ex63.Rnw:125-129
###################################################
layout.2 <- list("sp.points", jura.cal, pch=1, cex=1.4*jura.cal$Co/max(jura.cal$Co), col="white")
print(spplot(k.sim.4, zcol=1:4, col.regions=bpy.colors(64), 
       main="Conditional simulations, Jura Co (ppm), OK",
       sp.layout=list(layout.2)))


###################################################
### code chunk number 8: ex63.Rnw:147-150
###################################################
k.ok <- krige(Co ~ 1, loc=jura.cal, newdata=jura.grid, model=vmf)
print(spplot(k.ok, zcol="var1.pred", col.regions=bpy.colors(64), main="OK prediction, Jura Co (ppm)", sp.layout=list(layout.2)))
rm(layout.2)


###################################################
### code chunk number 9: ex63.Rnw:169-178
###################################################
vs.1 <- variogram(sim1 ~ 1, loc=k.sim.4)
vs.2 <- variogram(sim2 ~ 1, loc=k.sim.4)
vs.3 <- variogram(sim3 ~ 1, loc=k.sim.4)
vs.4 <- variogram(sim4 ~ 1, loc=k.sim.4)
gamma.max=ceiling(max(vs.1$gamma, vs.2$gamma, vs.3$gamma, vs.4$gamma, sum(vmf[,"psill"])))
p.1 <- plot(vs.1, model=vmf, ylim=c(0,gamma.max), main="Simulation 1")
p.2 <- plot(vs.2, model=vmf, ylim=c(0,gamma.max), main="Simulation 2")
p.3 <- plot(vs.3, model=vmf, ylim=c(0,gamma.max), main="Simulation 3")
p.4 <- plot(vs.4, model=vmf, ylim=c(0,gamma.max), main="Simulation 4")


###################################################
### code chunk number 10: ex63.Rnw:182-186
###################################################
print(p.1, split=c(1,1,2,2), more=T)
print(p.2, split=c(1,2,2,2), more=T)
print(p.3, split=c(2,1,2,2), more=T)
print(p.4, split=c(2,2,2,2), more=F)


###################################################
### code chunk number 11: ex63.Rnw:189-190
###################################################
rm(vs.1, vs.2, vs.3, vs.4, p.1, p.2, p.3, p.4, gamma.max)


###################################################
### code chunk number 12: ex63.Rnw:246-249
###################################################
if (file.exists("./ds/jura/cooked/JuraSimU4.RData")) 
  { load("./ds/jura/cooked/JuraSimU4.RData") } else
  { set.seed(621); k.sim.4.u <- krige(z ~ 1, loc=NULL, newdata=jura.grid, model=vmf, nsim=4, nmax=128, beta=mean(jura.cal$Co), dummy=T) }


###################################################
### code chunk number 13: ex63.Rnw:252-254 (eval = FALSE)
###################################################
## set.seed(621); 
## k.sim.4.u <- krige(z ~ 1, loc=NULL, newdata=jura.grid, model=vmf, nsim=4, nmax=128, beta=mean(jura.cal$Co), dummy=T)


###################################################
### code chunk number 14: ex63.Rnw:259-260
###################################################
if (!file.exists("./ds/jura/cooked/JuraSimU4.RData")) save(k.sim.4.u, file="./ds/jura/cooked/JuraSimU4.RData")


###################################################
### code chunk number 15: ex63.Rnw:267-268
###################################################
summary(k.sim.4.u)


###################################################
### code chunk number 16: ex63.Rnw:272-274
###################################################
print(spplot(k.sim.4.u, zcol=1:4, col.regions=bpy.colors(64), 
       main="Unconditional simulations, Co variogram model"))


###################################################
### code chunk number 17: ex63.Rnw:296-310
###################################################
c0 <- vmf[1,"psill"]; c1 <- vmf[2,"psill"]; a <- vmf[2,"range"]
set.seed(621)
k.sim.u.sph <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                     model=vgm(c1,"Sph",a,c0), nsim=1, nmax=128,
                     beta=mean(jura.cal$Co), dummy=T)
k.sim.u.pen <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                     model=vgm(c1,"Pen",a,c0), nsim=1, nmax=128,
                     beta=mean(jura.cal$Co), dummy=T)
k.sim.u.exp <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                     model=vgm(c1,"Exp",a/3,c0), nsim=1, nmax=128,
                     beta=mean(jura.cal$Co), dummy=T)
k.sim.u.gau <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                     model=vgm(c1,"Gau",a/sqrt(3),c0), nsim=1,
                     nmax=128, beta=mean(jura.cal$Co), dummy=T)


###################################################
### code chunk number 18: ex63.Rnw:321-325
###################################################
p.1 <- show.vgms(max=round(a*1.4,2), sill=round(c1,2), range=round(a,2), nugget=round(c0,2), models="Sph")
p.2 <- show.vgms(max=round(a*1.4,2), sill=round(c1,2), range=round(a,2), nugget=round(c0,2), models="Pen")
p.3 <- show.vgms(max=round(a*1.4,2), sill=round(c1,2), range=round(a/3,2), nugget=round(c0,2), models="Exp")
p.4 <- show.vgms(max=round(a*1.4,2), sill=round(c1,2), range=round(a/sqrt(3),2), nugget=round(c0,2), models="Gau")


###################################################
### code chunk number 19: ex63.Rnw:329-333
###################################################
print(p.1, split=c(1,1,2,2), more=T)
print(p.2, split=c(2,1,2,2), more=T)
print(p.3, split=c(1,2,2,2), more=T)
print(p.4, split=c(2,2,2,2), more=F)


###################################################
### code chunk number 20: ex63.Rnw:337-343
###################################################
k.sim.u <- k.sim.u.sph
names(k.sim.u) <- "sim.sph"
k.sim.u$sim.pen <- k.sim.u.pen$sim1
k.sim.u$sim.exp <- k.sim.u.exp$sim1
k.sim.u$sim.gau <- k.sim.u.gau$sim1
spplot(k.sim.u, zcol=c(3,4,1,2), col.regions=bpy.colors(64))


###################################################
### code chunk number 21: ex63.Rnw:358-372
###################################################
c.total <- sum(vmf[,"psill"]); a <- vmf[2,"range"]
set.seed(621)
k.sim.u.sph.0 <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                       model=vgm(c.total,"Sph",a,0), nsim=1,
                       nmax=128, beta=mean(jura.cal$Co), dummy=T)
k.sim.u.sph.2 <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                       model=vgm(c.total*.8,"Sph",a,c.total*.2), nsim=1,
                       nmax=128, beta=mean(jura.cal$Co), dummy=T)
k.sim.u.sph.4 <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                       model=vgm(c.total*.6,"Sph",a,c.total*.4), nsim=1,
                       nmax=128, beta=mean(jura.cal$Co), dummy=T)
k.sim.u.sph.6 <- krige(z ~ 1, loc=NULL, newdata=jura.grid,
                       model=vgm(c.total*.4,"Sph",a,c.total*.6), nsim=1,
                       nmax=128, beta=mean(jura.cal$Co), dummy=T)


###################################################
### code chunk number 22: ex63.Rnw:380-384
###################################################
p.1 <- show.vgms(max=round(a*1.2), sill=round(c.total,2),  range=round(a,2), models="Sph")
p.2 <- show.vgms(max=round(a*1.2), sill=round(c.total*.8,2), nugget=round(c.total*.2,2), range=round(a,2), models="Sph")
p.3 <- show.vgms(max=round(a*1.2), sill=round(c.total*.6,2),  nugget=round(c.total*.4,4), range=round(a,2), models="Sph")
p.4 <- show.vgms(max=round(a*1.2), sill=round(c.total*.4,2),  nugget=round(c.total*.6,2), range=round(a,2), models="Sph")


###################################################
### code chunk number 23: ex63.Rnw:389-393
###################################################
print(p.1, split=c(1,1,2,2), more=T)
print(p.2, split=c(2,1,2,2), more=T)
print(p.3, split=c(1,2,2,2), more=T)
print(p.4, split=c(2,2,2,2), more=F)


###################################################
### code chunk number 24: ex63.Rnw:399-405
###################################################
k.sim.u <- k.sim.u.sph.0
names(k.sim.u) <- "sim.sph.0"
k.sim.u$sim.sph.20 <- k.sim.u.sph.2$sim1
k.sim.u$sim.sph.40 <- k.sim.u.sph.4$sim1
k.sim.u$sim.sph.60 <- k.sim.u.sph.6$sim1
spplot(k.sim.u, zcol=c(3,4,1,2), col.regions=bpy.colors(64))


###################################################
### code chunk number 25: ex63.Rnw:417-419 (eval = FALSE)
###################################################
## rm(k.sim.4.u, k.sim.u, k.sim.u.sph, k.sim.u.pen, k.sim.u.exp, k.sim.u.gau,k.sim.u.sph.0,k.sim.u.sph.2,k.sim.u.sph.4,k.sim.u.sph.6, c0, c1, c.total, a)
## rm(p.1,p.2,p.3,p.4)


