### R code from vignette source 'ex81.Rnw'

###################################################
### code chunk number 1: ex81.Rnw:20-27
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
## keep previous simulation object if defined
rm(list=setdiff(ls(),ls(pat='k.sim')))
# rm(list=ls())
while(length(dev.list()) > 0) dev.off()
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex81.Rnw:42-44 (eval = FALSE)
###################################################
## load("JuraEx4.RData")
## ls()


###################################################
### code chunk number 3: ex81.Rnw:47-50
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 4: ex81.Rnw:53-55
###################################################
load("/Users/rossiter/data/edu/dgeostats/ex/ds/jura/cooked/JuraEx4.RData")
ls()


###################################################
### code chunk number 5: ex81.Rnw:68-69
###################################################
set.seed(201302)


###################################################
### code chunk number 6: ex81.Rnw:74-80 (eval = FALSE)
###################################################
## system.time(
## k.sim <- krige(Co ~ 1, loc = jura.cal,
##                newdata = jura.grid, 
##                model = vmf, nsim = 1,
##                nmax = 256)
## )


###################################################
### code chunk number 7: ex81.Rnw:94-97
###################################################
if(!is.element("k.sim", ls()))
  { k.sim <- krige(Co ~ 1, loc = jura.cal, newdata = jura.grid, 
    model = vmf, nsim = 1, nmax = 256) }


###################################################
### code chunk number 8: ex81.Rnw:102-109
###################################################
layout.2 <- list("sp.points", jura.cal, pch=21,
                 cex=1.2*jura.cal$Co/max(jura.cal$Co),
                 col="black", fill="darkgreen")
print(spplot(k.sim, zcol=1, col.regions=bpy.colors(64),
       main="Simulated population, Jura Co (ppm)",
       sp.layout=list(layout.2)))
rm(layout.2)


###################################################
### code chunk number 9: ex81.Rnw:120-122
###################################################
mean(k.sim$sim1)
var(k.sim$sim1)


###################################################
### code chunk number 10: ex81.Rnw:142-148
###################################################
samp.rand <- spsample(jura.grid, n=100, type="random")
str(samp.rand)
plot(coordinates(samp.rand), asp=1, xlab="E", ylab="N",
     xlim=c(0,5.5), ylim=c(0,6),
     main="Completely random sample, 100 points")
grid(lty=1, col="lightblue")


###################################################
### code chunk number 11: ex81.Rnw:186-189
###################################################
class(k.sim)
Co.rand <- over(samp.rand, k.sim)
str(Co.rand)


###################################################
### code chunk number 12: ex81.Rnw:195-199
###################################################
ov <- over(samp.rand, as(k.sim, "SpatialPixels"))
head(ov)
Co.rand <- k.sim$sim1[ov]
str(Co.rand)


###################################################
### code chunk number 13: ex81.Rnw:214-219
###################################################
(ix <- which(is.na(Co.rand)))
if (length(ix) > 0) {
  Co.rand <- Co.rand[-ix];
  samp.rand <- samp.rand[-ix]
}


###################################################
### code chunk number 14: ex81.Rnw:226-230
###################################################
summary(Co.rand)
summary(k.sim$sim1)
var(Co.rand)
var(k.sim$sim1)


###################################################
### code chunk number 15: ex81.Rnw:240-244
###################################################
hist.rand <- hist(Co.rand, breaks=seq(-4,24,by=2), plot=F)
str(hist.rand)
hist.sim <- hist(k.sim$sim1, breaks=seq(-4,24,by=2), plot=F)
str(hist.sim)


###################################################
### code chunk number 16: ex81.Rnw:250-251
###################################################
to.plot <- rbind(samp=hist.rand$density, pop=hist.sim$density)


###################################################
### code chunk number 17: ex81.Rnw:259-262
###################################################
barplot(to.plot, beside=T, col=c("lavender", "cornsilk"),
        main="Histogram of Co frequency",
        sub="random sample (left), population (right)")


###################################################
### code chunk number 18: ex81.Rnw:271-272
###################################################
rm(hist.rand, hist.sim, to.plot)


###################################################
### code chunk number 19: extract.co
###################################################
Co.rand <- data.frame(Co = Co.rand)
str(Co.rand)
coordinates(Co.rand) <- coordinates(samp.rand)
str(Co.rand)


###################################################
### code chunk number 20: ex81.Rnw:295-299
###################################################
v <- variogram(Co ~ 1, loc=Co.rand)
print(plot(v, pl=T,
           model=vmf,
           main="Variogram of Co ppm^2, from random sample"))


###################################################
### code chunk number 21: ex81.Rnw:313-317
###################################################
(vf <- fit.variogram(v, vmf))
print(vmf)
print(plot(v, pl=T, model=vf,
           main="Variogram of Co ppm^2, fitted from random sample"))


###################################################
### code chunk number 22: ex81.Rnw:398-400
###################################################
samp.grid <- spsample(jura.grid, n=100, type="regular", offset=c(0.5,0.5))
str(samp.grid)


###################################################
### code chunk number 23: ex81.Rnw:403-406
###################################################
plot(coordinates(samp.grid), asp=1, xlab="E", ylab="N",
     xlim=c(0,5.5), ylim=c(0,6))
grid(lty=1, col="lightblue")


###################################################
### code chunk number 24: ex81.Rnw:422-425
###################################################
samp.grid <- as.data.frame(samp.grid)
samp.grid$x1 <- samp.grid$x1 + rnorm(n=length(samp.grid$x1), mean=0, sd=0.03)
samp.grid$x2 <- samp.grid$x2 + rnorm(n=length(samp.grid$x2), mean=0, sd=0.03)


###################################################
### code chunk number 25: ex81.Rnw:433-437
###################################################
(pts.outside <- which((samp.grid$x1 < bbox(k.sim)[1,"min"])
 | (samp.grid$x1 > bbox(k.sim)[1,"max"])
 | (samp.grid$x2 < bbox(k.sim)[2,"min"])
 | (samp.grid$x2 > bbox(k.sim)[2,"max"])))


###################################################
### code chunk number 26: ex81.Rnw:442-445
###################################################
samp.grid <- samp.grid[setdiff(1:length(samp.grid$x1), pts.outside),]
str(samp.grid)
rm(pts.outside)


###################################################
### code chunk number 27: ex81.Rnw:451-452
###################################################
coordinates(samp.grid) <- ~ x1 + x2


###################################################
### code chunk number 28: ex81.Rnw:455-457
###################################################
plot(coordinates(samp.grid), asp=1, xlab="E", ylab="N")
grid(lty=1, col="lightblue")


###################################################
### code chunk number 29: ex81.Rnw:495-507
###################################################
poly.1 <- Polygon(cbind(
          c(bbox(jura.grid)[1,"min"], bbox(jura.grid)[1,"min"],
                bbox(jura.grid)[1,"max"], bbox(jura.grid)[1,"max"],
                bbox(jura.grid)[1,"min"]
              ),
          c(bbox(jura.grid)[2,"min"], bbox(jura.grid)[2,"max"],
                bbox(jura.grid)[2,"max"], bbox(jura.grid)[2,"min"],
                bbox(jura.grid)[2,"min"]
              )
               )
          )
str(poly.1)


###################################################
### code chunk number 30: ex81.Rnw:512-514
###################################################
polys <- Polygons(list(poly.1), "boundary")
str(polys)


###################################################
### code chunk number 31: ex81.Rnw:519-521
###################################################
bboxPoly <- SpatialPolygons(list(polys))
str(bboxPoly)


###################################################
### code chunk number 32: ex81.Rnw:540-546
###################################################
set.seed(316)
samp.grid <- spsample(jura.grid, n=100, type="regular", offset=c(0.5,0.5))
samp.grid <- as.data.frame(samp.grid)
samp.grid$x1 <- samp.grid$x1 + rnorm(n=length(samp.grid$x1), mean=0, sd=0.1)
samp.grid$x2 <- samp.grid$x2 + rnorm(n=length(samp.grid$x2), mean=0, sd=0.1)
coordinates(samp.grid) <- ~ x1 + x2


###################################################
### code chunk number 33: ex81.Rnw:551-555
###################################################
ov <- over(samp.grid, bboxPoly)
sum(is.na(ov))
samp.grid[is.na(ov)]
bbox(jura.grid)


###################################################
### code chunk number 34: ex81.Rnw:564-566
###################################################
print(plot(bboxPoly, col="lightgray"))
points(samp.grid, col=ifelse(is.na(ov),"red","green"), pch=20, cex=2)


###################################################
### code chunk number 35: ex81.Rnw:575-577
###################################################
samp.grid <- samp.grid[!is.na(ov)]
summary(samp.grid)


###################################################
### code chunk number 36: ex81.Rnw:584-585
###################################################
rm(poly.1, polys, bboxPoly, ov)


###################################################
### code chunk number 37: ex81.Rnw:598-599
###################################################
Co.grid <- over(samp.grid, k.sim)$sim1


###################################################
### code chunk number 38: ex81.Rnw:606-610
###################################################
summary(Co.grid)
summary(k.sim$sim1)
var(Co.grid, na.rm=TRUE)
var(k.sim$sim1)


###################################################
### code chunk number 39: ex81.Rnw:618-628
###################################################
hist.grid <- hist(Co.grid, breaks=seq(-4,24,by=2),
                  plot=F)
hist.sim <- hist(k.sim$sim1, breaks=seq(-4,24,by=2),
                 plot=F)
to.plot <- rbind(samp=hist.grid$density,
                 pop=hist.sim$density)
barplot(to.plot, beside=T, col=c("lavender", "cornsilk"),
        main="Histogram of Co frequency", 
        sub="grid sample (left), population (right)")
rm(hist.grid, hist.sim, to.plot)


###################################################
### code chunk number 40: ex81.Rnw:642-649
###################################################
Co.grid <- data.frame(Co = Co.grid)
coordinates(Co.grid) <- coordinates(samp.grid)
(ix <- which(is.na(Co.grid$Co)))
if (length(ix) > 0) {
  Co.grid <- Co.grid[-ix,];
  samp.grid <- samp.grid[-ix,]
}


###################################################
### code chunk number 41: ex81.Rnw:652-656
###################################################
str(Co.grid)
v <- variogram(Co ~ 1, location=Co.grid)
print(plot(v, pl=T, model=vf, 
           main="Variogram of Co ppm^2, grid sample"))


###################################################
### code chunk number 42: ex81.Rnw:717-719
###################################################
err.grid <- ossfim(seq(0.1,0.4,0.05),seq(0,0.1,0.02),vmf)
str(err.grid)


###################################################
### code chunk number 43: ex81.Rnw:730-735
###################################################
plot.1 <- levelplot(kriging.se ~ spacing+block.size, err.grid, col.regions=bpy.colors(64))
plot.2 <- contourplot(kriging.se ~ spacing+block.size, err.grid)
print(plot.1, split = c(1,1,2,1), more=T)
print(plot.2, split = c(2,1,2,1), more=F)
rm(plot.1, plot.2)


###################################################
### code chunk number 44: ex81.Rnw:746-747
###################################################
err.grid[err.grid$block.size==0,]


###################################################
### code chunk number 45: ex81.Rnw:752-753
###################################################
err.grid[err.grid$spacing==0.1,]


###################################################
### code chunk number 46: ex81.Rnw:764-767
###################################################
tmp <- err.grid[err.grid$kriging.se < 1.5,]
tmp[order(tmp$kriging.se),]
rm(tmp)


###################################################
### code chunk number 47: ex81.Rnw:778-779
###################################################
rm(samp.rand, samp.grid, Co.rand, Co.grid, v, vf, err.grid, ix)


