### R code from vignette source 'ex8a2.Rnw'

###################################################
### code chunk number 1: ex8a2.Rnw:19-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
## clean workspace
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex8a2.Rnw:27-30
###################################################
require(gstat)
require(sp)
require(lattice)


###################################################
### code chunk number 3: ex8a2.Rnw:83-232
###################################################
ssa.ok <- function(s.init, s.area, s.res,
                   s.model, s.fix.pts=NA, s.f=mean, s.decay=256,
                   s.max.shift = sqrt(2)/4,
                   s.alpha=0.99, s.prob=0.8,
                   eq.steps=200,
                   max.steps=NA, s.prec=NA) {

  
  # helper function: compute fitness by kriging variance
  # interpolation `grid' and variogram model `s.model'
  #   are in callers environment
  # data field must be named `z'
  obj.k <- function(pts, f) {
      k <- krige(z ~ 1, loc=pts, model=s.model,
                 newdata=grid, debug.level=0)
      return(f(k$var1.var))
    }
  
  # helper function: compute initial temperature
    metr.temp.init <- function(n.steps) {
      s <- s.init # initial `fitness' in environ
      max.shift <- max.dist*sqrt(2)/4
      sum.fit <- 0; i <- 0 
      while (i < n.steps) {
        pt <- sample(1:n.pts, 1)
        pt.old <- coordinates(scheme)[pt,]
        s.try <- NA
        while (is.logical(s.try)) {
          xnew <- pt.old[1] + runif(1, min=-max.shift/2,
                                    max=max.shift/2)
          ynew <- pt.old[2] + runif(1, min=-max.shift/2,
                                    max=max.shift/2)
          pt.new <- data.frame(x = xnew, y = ynew)
          coordinates(pt.new) <- c(1,2)
          # over() requires identical CRS, note order
          proj4string(pt.new) <- proj4string(s.area)
          if (!is.na(over(pt.new, s.area))) s.try <- s
        }
        s.try@coords[pt,] <- c(xnew, ynew)
        # fitness function in environ
        if (is.logical(s.fix.pts)) pts <- s.try
        else pts <- rbind(s.fix.pts, s.try)
        # check new fitness, only use if worse
        fit.new <- obj.k(pts, s.f)
        if (fit.new > fitness) {
          sum.fit <- sum.fit + fit.new
          i <- i+1 }
      } # note change of sign to ensure negative sum
      return((fitness-(sum.fit/n.steps))/log(s.prob))
    }

    ## main body
    ## 1 - setup
    # 1.1 - set up maximum distance
    max.dist <- sqrt(((bbox(s.area)[1,"max"]
                       - bbox(s.area)[1,"min"])^2)
                     + ((bbox(s.area)[2,"max"]
                         - bbox(s.area)[2,"min"])^2))
    n.pts <- length(s.init$z)

    # 1.2 - set up interpolation grid -- may not be full
    #       so leave as SpatialPoints, do not promote to SpatialGrid
  grid <- spsample(s.area, n=s.res^2, type="regular")
  if (is.logical(s.fix.pts)) pts <- s.init
  else pts <- rbind(s.fix.pts, s.init)
  fitness <- obj.k(pts, s.f)  # initial fitness
    
    # 1.3 - if precision was not specified, set as 3rd significant
    #     figure of initial fitness
    i <- 0
    while (is.na(s.prec)) {
      if (fitness%/%(10^-i) != 0) s.prec=i+4 else i <- i + 1
    }
    
    # 1.4 - initialize temperature
    metr.temp <- 
      ret.metr.temp.init <-
      metr.temp.init(128); # this is enough for a rough guess

    # 1.5 - set up to record evolution of fits
    fits <- matrix(nrow = 0, ncol=4)
    colnames(fits) <- c("actual","proposed","max.shift","temperature")
    this.step <- 0; equal.steps <- 0;
    s <- s.init;
    
    ## 2 - main loop
    # 2.1 get a proposed new point in the study area
    repeat {
      max.shift <- (max.dist*s.max.shift)*
        exp(-this.step/s.decay)
      metr.temp <- metr.temp * s.alpha

      pt <- sample(1:n.pts, 1)
      pt.old <- coordinates(s)[pt,]
      repeat {
        xnew <- round(pt.old[1] + runif(1, min=-max.shift,
                                       max=max.shift),prec)
        ynew <- round(pt.old[2] + runif(1, min=-max.shift,
                                        max=max.shift),prec)
        pt.new <- data.frame(x = xnew, y = ynew)
        coordinates(pt.new) <- ~ x + y
        proj4string(pt.new) <- proj4string(p)
        if (!is.na(over(pt.new, p))) break
      }

        # 2.2 increment step when we have a proposed point
      this.step <- this.step + 1;
      s.try <- s;
        # update the selected point's coordinates
      s.try@coords[pt,] <- c(xnew, ynew);
        # 2.3 new fitness, to the desired precision
      if (is.logical(s.fix.pts)) pts <- s.try
      else pts <- rbind(s.fix.pts, s.try)
      fitness.new <-  round(obj.k(pts, s.f), s.prec);

        # 2.4 acceptance criteria; maybe update scheme
        if (fitness.new < fitness) {
            s <- s.try;
            fitness <- fitness.new;
            equal.steps <- 0
        } else if (runif(1) < (metr.temp
                               * exp(fitness - fitness.new))) {
                s <- s.try;
                fitness <- fitness.new;
                equal.steps <- 0
        } else { equal.steps <- (equal.steps + 1) }

      # 2.5 save record of fits
      fits <- rbind(fits, c(fitness, fitness.new,
                            max.shift, metr.temp))

      # 2.6 check stopping criteria
      if (equal.steps >= eq.steps) break;
      if (!is.na(max.steps) & (this.step >= max.steps)) break;
    }
      
    # 3 - plot the fitness vs. step
    plot(1:length(fits[,1]), fits[,"actual"],
         xlab="Step", ylab="Fitness function", type="l",
         main="Fitness function vs. step",
         sub="Black: actual; red: proposed",
         ylim=c(min(fits[,1]), max(fits[,2])))
      lines(1:length(fits[,1]), fits[,"proposed"],
            type="l", col="red", lty=2)
    
    # 4 - return the final sampling scheme
    #     and the computed annealing parameters
    return(list(scheme=s, metr.temp=ret.metr.temp.init, s.prec=s.prec))
  }


###################################################
### code chunk number 4: ex8a2.Rnw:269-273
###################################################
tmp <- file("ssa_ok.R", open="wt")
cat("ssa.ok <- ", file=tmp) 
capture.output(print(ssa.ok), file=tmp)
close(tmp)


###################################################
### code chunk number 5: ex8a2.Rnw:278-279 (eval = FALSE)
###################################################
## source("ssa_ok.R")


###################################################
### code chunk number 6: ex8a2.Rnw:284-285
###################################################
save(ssa.ok, file="ssa_ok.RData")


###################################################
### code chunk number 7: ex8a2.Rnw:290-291 (eval = FALSE)
###################################################
## load("ssa_ok.RData")


###################################################
### code chunk number 8: ex8a2.Rnw:306-318
###################################################
p <- SpatialPolygonsDataFrame(
      SpatialPolygons(
        list(Polygons(
         list(Polygon(
          matrix(c(0,0, 0,1, 1,1, 1,0, 0,0),
                 byrow=T, nrow=5, ncol=2) # matrix
                     ) # Polygon
                    ) # list of Polygon
            , ID=1 ) # Polygons, with identifier
                 ) # list of Polygons
         ) # Spatial Polygons
, data=data.frame(id=1)) # SpatialPolygonsDataFrame


###################################################
### code chunk number 9: ex8a2.Rnw:323-325
###################################################
fix.pts <- data.frame(x = c(.2,.6), y=c(.6, .2), z=0)
coordinates(fix.pts) <- ~ x + y


###################################################
### code chunk number 10: ex8a2.Rnw:334-343
###################################################
prec <- 4; n.pts <- 10
set.seed(619)
repeat {
  try <- spsample(p, n=n.pts, type="hexagonal");
  if (length(coordinates(try)[,1]) == n.pts) break
  }
scheme <- SpatialPointsDataFrame(try, data.frame(z=rep(0,n.pts)))
scheme@coords <- round(scheme@coords, prec)
rm(try)


###################################################
### code chunk number 11: ex8a2.Rnw:350-360
###################################################
print(spplot(p, xlab="E", ylab="N",
             col.regions="slategray3",
             main="Initial sampling scheme",
             sub="Fixed: yellow; Moveable: white",
             scales=list(draw=T),
             sp.layout = list(list("sp.points",
               scheme, col="white", pch=20, cex=1.6),
               list("sp.points", fix.pts, col="yellow",
                    pch=20, cex=1.6))
       ))


###################################################
### code chunk number 12: ex8a2.Rnw:393-403
###################################################
max.dist <- sqrt(((bbox(p)[1,"max"] - bbox(p)[1,"min"])^2) + ((bbox(p)[2,"max"] - bbox(p)[2,"min"])^2))
vm <- vgm(psill=1, model="Exp", range=max.dist/(3*3), 0)
#
#
# debug(ssa.ok)
#
#
time <- system.time(
                    tmp <- ssa.ok(s.init=scheme, s.fix.pts=fix.pts, s.area=p, s.res=100, s.model=vm, s.f=mean, s.prob=0.9, s.alpha=0.999, s.decay=1024, eq.steps=200)
            )


###################################################
### code chunk number 13: show.ssa.ok.results
###################################################
print(time)
print(paste("Precision of fitness matching:", tmp[["s.prec"]],
                "decimal places"))
print(paste("Initial Metropolis temperature:",
                round(tmp[["metr.temp"]], 4)))
s.final <- tmp[["scheme"]]


###################################################
### code chunk number 14: show.final (eval = FALSE)
###################################################
## print(s.final)
## grid <- spsample(p, n=100^2, type="regular")
## gridded(grid) = T; fullgrid(grid) = T
## k <- krige(z ~ 1, loc=rbind(fix.pts, s.final),
##            model=vm, newdata=grid, debug.level=0)
## gridded(k) = T; fullgrid(k) = T
## pts.s <- list("sp.points", s.final, col="white",
##               pch=20, cex=1.6)
## pts.f <- list("sp.points", fix.pts, col="blue",
##               pch=20, cex=1.6)
## print(spplot(k, zcol="var1.var",
##              col.regions=heat.colors(64),
##              main=paste("Final sampling scheme"),
##              sub=paste("Mean, max kriging variance:",
##                round(mean(k$var1.var),4),";",
##                round(max(k$var1.var),4)),
##              sp.layout = list(pts.s, pts.f)
##              ))
## rm(grid, k, pts.s, pts.f)


###################################################
### code chunk number 15: ex8a2.Rnw:446-447
###################################################
print(s.final)
grid <- spsample(p, n=100^2, type="regular")
gridded(grid) = T; fullgrid(grid) = T
k <- krige(z ~ 1, loc=rbind(fix.pts, s.final),
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T; fullgrid(k) = T
pts.s <- list("sp.points", s.final, col="white",
              pch=20, cex=1.6)
pts.f <- list("sp.points", fix.pts, col="blue",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Final sampling scheme"),
             sub=paste("Mean, max kriging variance:",
               round(mean(k$var1.var),4),";",
               round(max(k$var1.var),4)),
             sp.layout = list(pts.s, pts.f)
             ))
rm(grid, k, pts.s, pts.f)


###################################################
### code chunk number 16: ex8a2.Rnw:452-453
###################################################
s.final.mean.1 <- s.final


###################################################
### code chunk number 17: ex8a2.Rnw:467-468
###################################################
time <- system.time(tmp <- ssa.ok(s.init=scheme, s.fix.pts=fix.pts, s.area=p, s.res=100, s.model=vm, s.f=max, s.prob=0.9, s.alpha=0.999, s.decay=1024, eq.steps=200))


###################################################
### code chunk number 18: ex8a2.Rnw:473-474
###################################################
print(time)
print(paste("Precision of fitness matching:", tmp[["s.prec"]],
                "decimal places"))
print(paste("Initial Metropolis temperature:",
                round(tmp[["metr.temp"]], 4)))
s.final <- tmp[["scheme"]]


###################################################
### code chunk number 19: ex8a2.Rnw:483-484
###################################################
print(s.final)
grid <- spsample(p, n=100^2, type="regular")
gridded(grid) = T; fullgrid(grid) = T
k <- krige(z ~ 1, loc=rbind(fix.pts, s.final),
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T; fullgrid(k) = T
pts.s <- list("sp.points", s.final, col="white",
              pch=20, cex=1.6)
pts.f <- list("sp.points", fix.pts, col="blue",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Final sampling scheme"),
             sub=paste("Mean, max kriging variance:",
               round(mean(k$var1.var),4),";",
               round(max(k$var1.var),4)),
             sp.layout = list(pts.s, pts.f)
             ))
rm(grid, k, pts.s, pts.f)


###################################################
### code chunk number 20: ex8a2.Rnw:507-516
###################################################
set.seed(318)
repeat {
  try <- spsample(p, n=9, type="regular");
  if (length(coordinates(try)[,1]) == 9) break
  }
try <- rbind(try, spsample(p, n=1, type="random"))
scheme <- SpatialPointsDataFrame(try, data.frame(z=rep(0,10)))
scheme@coords <- round(scheme@coords, prec)
rm(try)


###################################################
### code chunk number 21: ex8a2.Rnw:521-529
###################################################
print(spplot(p, xlab="E", ylab="N", col.regions="slategray3",
             main="Initial sampling scheme (2)",
             sub="Fixed: yellow; Moveable: white", scales=list(draw=T),
             sp.layout = list(list("sp.points", scheme, col="white",
               pch=20, cex=1.6),
               list("sp.points", fix.pts, col="yellow",
                    pch=20, cex=1.6))
       ))


###################################################
### code chunk number 22: ex8a2.Rnw:537-538
###################################################
time <- system.time(tmp <- ssa.ok(s.init=scheme, s.fix.pts=fix.pts, s.area=p, s.res=100, s.model=vm, s.f=mean, s.prob=0.9, s.alpha=0.999, s.decay=1024, eq.steps=200))


###################################################
### code chunk number 23: ex8a2.Rnw:542-543
###################################################
print(time)
print(paste("Precision of fitness matching:", tmp[["s.prec"]],
                "decimal places"))
print(paste("Initial Metropolis temperature:",
                round(tmp[["metr.temp"]], 4)))
s.final <- tmp[["scheme"]]


###################################################
### code chunk number 24: ex8a2.Rnw:548-549
###################################################
print(s.final)
grid <- spsample(p, n=100^2, type="regular")
gridded(grid) = T; fullgrid(grid) = T
k <- krige(z ~ 1, loc=rbind(fix.pts, s.final),
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T; fullgrid(k) = T
pts.s <- list("sp.points", s.final, col="white",
              pch=20, cex=1.6)
pts.f <- list("sp.points", fix.pts, col="blue",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Final sampling scheme"),
             sub=paste("Mean, max kriging variance:",
               round(mean(k$var1.var),4),";",
               round(max(k$var1.var),4)),
             sp.layout = list(pts.s, pts.f)
             ))
rm(grid, k, pts.s, pts.f)


###################################################
### code chunk number 25: ex8a2.Rnw:561-573
###################################################
print(spplot(p, xlab="E", ylab="N", col.regions="white",
             main="Comparing final sampling schemes",
             sub="Fixed: blue; Moveable: green (scheme 1), red (scheme 2)",
             scales=list(draw=T),
             sp.layout = list(
               list("sp.points", s.final, col="red",
                    pch=20, cex=1.6),
               list("sp.points", s.final.mean.1, col="green",
                    pch=20, cex=1.6),
               list("sp.points", fix.pts, col="blue",
                    pch=20, cex=1.6))
             ))


###################################################
### code chunk number 26: ex8a2.Rnw:580-581
###################################################
rm(max.dist,n.pts,p,prec,s.final,scheme,vm,ssa.ok,s.final.mean.1,time)


