### R code from vignette source 'ex8a3.Rnw'

###################################################
### code chunk number 1: ex8a3.Rnw:19-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
## clean workspace
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex8a3.Rnw:27-30
###################################################
require(gstat)
require(sp)
require(lattice)


###################################################
### code chunk number 3: ex8a3.Rnw:45-47
###################################################
require(mapdata)
tmp <- map('world',"Spain", fill=TRUE, plot=T, col="lightblue")


###################################################
### code chunk number 4: ex8a3.Rnw:63-67
###################################################
require(maptools)
Spain.polys <- map2SpatialPolygons(tmp, IDs=tmp$names,
     proj4string=
     CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))


###################################################
### code chunk number 5: ex8a3.Rnw:91-102
###################################################
require(rgdal)
bbox(Spain.polys)
laea_crs <-
   "+proj=laea +lat_0=52 +lon_0=10 +x_0=4321000 +y_0=3210000 +ellps=GRS80 +units=m +no_defs"
Spain.polys <- spTransform(Spain.polys, CRS(laea_crs))
(bb <- bbox(Spain.polys))
(max.dist <- sqrt(((bb[1,"max"] - bb[1,"min"])^2)
                + ((bb[2,"max"] - bb[2,"min"])^2)
                  ))
print(paste("Diagonal of bounding box:",
            round(max.dist/1000), "km"))


###################################################
### code chunk number 6: ex8a3.Rnw:112-113
###################################################
load("ssa_ok.RData")


###################################################
### code chunk number 7: ex8a3.Rnw:120-129
###################################################
prec <- 4; n.pts <- 80
set.seed(316)
repeat {
  sample.try <- spsample(Spain.polys, n=n.pts, type="random");
  if (length(coordinates(sample.try)[,1]) == n.pts) break
  }
scheme <- SpatialPointsDataFrame(sample.try, data.frame(z=rep(0,n.pts)))
scheme@coords <- round(scheme@coords, prec)
rm(sample.try)


###################################################
### code chunk number 8: ex8a3.Rnw:137-140
###################################################
plot(Spain.polys, col="slategray2")
points(coordinates(scheme), col="black", bg="red", pch=21)
grid(lty=1)


###################################################
### code chunk number 9: ex8a3.Rnw:154-155
###################################################
vm <- vgm(psill=1, model="Exp", range=120000/3, 0)


###################################################
### code chunk number 10: show.krige (eval = FALSE)
###################################################
## res <- round(max.dist/sqrt(2)/10000)
## grid <- spsample(Spain.polys, n=res^2, type="regular")
## k <- krige(z ~ 1, loc=scheme,
##            model=vm, newdata=grid, debug.level=0)
## gridded(k) = T
## pts.s <- list("sp.points", scheme, col="white",
##               pch=20, cex=1.6)
## print(spplot(k, zcol="var1.var",
##              col.regions=heat.colors(64),
##              main=paste("Sampling scheme"),
##              sub=paste("Mean, max kriging variance:",
##              round(mean(k$var1.var),4),";",
##              round(max(k$var1.var),4)),
##              sp.layout = list(pts.s)
##              ))
## rm(grid, k, pts.s)


###################################################
### code chunk number 11: ex8a3.Rnw:181-182
###################################################
res <- round(max.dist/sqrt(2)/10000)
grid <- spsample(Spain.polys, n=res^2, type="regular")
k <- krige(z ~ 1, loc=scheme,
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T
pts.s <- list("sp.points", scheme, col="white",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Sampling scheme"),
             sub=paste("Mean, max kriging variance:",
             round(mean(k$var1.var),4),";",
             round(max(k$var1.var),4)),
             sp.layout = list(pts.s)
             ))
rm(grid, k, pts.s)


###################################################
### code chunk number 12: ex8a3.Rnw:198-203
###################################################
p <- Spain.polys
(res <- round(max.dist/sqrt(2)/10000))
time <- system.time(
                    tmp <- ssa.ok(s.init=scheme, s.area=p, s.res=res, s.model=vm, s.f=mean, s.prob=0.9, s.alpha=0.999, s.decay=1024, eq.steps=200, max.steps=1600)
            )


###################################################
### code chunk number 13: show.ssa.results
###################################################
print(time)
print(paste("Precision of fitness matching:", tmp[["s.prec"]],
                "decimal places"))
print(paste("Initial Metropolis temperature:",
                round(tmp[["metr.temp"]], 4)))
s.final <- tmp[["scheme"]]


###################################################
### code chunk number 14: ex8a3.Rnw:223-226
###################################################
plot(Spain.polys, col="slategray2")
points(coordinates(s.final), col="black", bg="red", pch=21)
grid(lty=1)


###################################################
### code chunk number 15: ex8a3.Rnw:234-236
###################################################
scheme <- s.final
res <- round(max.dist/sqrt(2)/10000)
grid <- spsample(Spain.polys, n=res^2, type="regular")
k <- krige(z ~ 1, loc=scheme,
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T
pts.s <- list("sp.points", scheme, col="white",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Sampling scheme"),
             sub=paste("Mean, max kriging variance:",
             round(mean(k$var1.var),4),";",
             round(max(k$var1.var),4)),
             sp.layout = list(pts.s)
             ))
rm(grid, k, pts.s)


###################################################
### code chunk number 16: ex8a3.Rnw:250-253
###################################################
time <- system.time(
                    tmp <- ssa.ok(s.init=scheme, s.area=p, s.res=res, s.model=vm, s.f=max, s.prob=0.9, s.alpha=0.999, s.decay=1024, eq.steps=200, max.steps=1600)
            )


###################################################
### code chunk number 17: ex8a3.Rnw:257-258
###################################################
print(time)
print(paste("Precision of fitness matching:", tmp[["s.prec"]],
                "decimal places"))
print(paste("Initial Metropolis temperature:",
                round(tmp[["metr.temp"]], 4)))
s.final <- tmp[["scheme"]]


###################################################
### code chunk number 18: ex8a3.Rnw:265-267
###################################################
scheme <- s.final
res <- round(max.dist/sqrt(2)/10000)
grid <- spsample(Spain.polys, n=res^2, type="regular")
k <- krige(z ~ 1, loc=scheme,
           model=vm, newdata=grid, debug.level=0)
gridded(k) = T
pts.s <- list("sp.points", scheme, col="white",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Sampling scheme"),
             sub=paste("Mean, max kriging variance:",
             round(mean(k$var1.var),4),";",
             round(max(k$var1.var),4)),
             sp.layout = list(pts.s)
             ))
rm(grid, k, pts.s)


