### R code from vignette source 'ex91.Rnw'

###################################################
### code chunk number 1: ex91.Rnw:20-24
###################################################
options(prompt="> ", continue="+ ", digits=8, width=65, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex91.Rnw:28-33
###################################################
require(sp)
require(gstat)
require(rgdal)
require(maptools)
require(lattice)


###################################################
### code chunk number 3: ex91.Rnw:62-65 (eval = FALSE)
###################################################
## vignette(package="sp")
## vignette("intro_sp")
## vignette("over", package="sp")


###################################################
### code chunk number 4: ex91.Rnw:89-94 (eval = FALSE)
###################################################
## require(sp)
## require(rgdal)
## require(maptools)
## require(gstat)
## require(lattice)


###################################################
### code chunk number 5: ex91.Rnw:122-126
###################################################
data(meuse)
coordinates(meuse) = ~ x + y
head(coordinates(meuse))
str(meuse)


###################################################
### code chunk number 6: ex91.Rnw:137-138
###################################################
proj4string(meuse)


###################################################
### code chunk number 7: ex91.Rnw:192-195
###################################################
EPSG <- make_EPSG()
(EPSG[grep("Amersfoort", fixed=T, EPSG$note), ])
rm(EPSG)


###################################################
### code chunk number 8: ex91.Rnw:227-230
###################################################
proj4string(meuse) <- CRS("+init=epsg:28992")
proj4string(meuse)
head(coordinates(meuse))


###################################################
### code chunk number 9: ex91.Rnw:266-268
###################################################
proj4string(meuse) <- CRS(paste(proj4string(meuse),"+towgs84=565.237,50.0087,465.658,-0.406857,0.350733,-1.87035,4.0812"))
proj4string(meuse)


###################################################
### code chunk number 10: ex91.Rnw:332-333
###################################################
proj4string(meuse) <- CRS("+proj=stere +lat_0=52.15616055555555 +lon_0=5.38763888888889 +k=0.999908 +x_0=155000 +y_0=463000 +ellps=bessel +units=m +no_defs +towgs84=565.2369,50.0087,465.658,-0.406857330322398,0.350732676542563,-1.8703473836068,4.0812")


###################################################
### code chunk number 11: ex91.Rnw:351-354
###################################################
meuse.wgs84 <- spTransform(meuse, CRS("+proj=longlat +datum=WGS84"))
proj4string(meuse.wgs84)
head(coordinates(meuse.wgs84))


###################################################
### code chunk number 12: ex91.Rnw:387-389
###################################################
(v.wgs84 <- variogram(log(zinc) ~1, loc=meuse.wgs84))
(v.rd <- variogram(log(zinc) ~1, loc=meuse))


###################################################
### code chunk number 13: ex91.Rnw:404-407
###################################################
(v.rd$dist - v.wgs84$dist*1000)*100
max(v.rd$dist-v.wgs84$dist*1000)*100
max(v.rd$dist-v.wgs84$dist*1000)/diff(bbox(meuse)["y",])*100


###################################################
### code chunk number 14: ex91.Rnw:440-441 (eval = FALSE)
###################################################
## list.files("./NY_data", pattern="NY8")


###################################################
### code chunk number 15: ex91.Rnw:444-445
###################################################
list.files("./ds/ASDAR/NY_data", pattern="NY8")


###################################################
### code chunk number 16: ex91.Rnw:454-456 (eval = FALSE)
###################################################
## NY8 <- readOGR("./NY_data", "NY8_utm18")
## cities <- readOGR("./NY_data", "NY8cities")


###################################################
### code chunk number 17: ex91.Rnw:460-464
###################################################
NY8 <- readOGR("./ds/ASDAR/NY_data", "NY8_utm18")
class(NY8)
cities <- readOGR("./ds/ASDAR/NY_data", "NY8cities")
class(cities)


###################################################
### code chunk number 18: ex91.Rnw:476-478
###################################################
proj4string(NY8)
proj4string(cities)


###################################################
### code chunk number 19: ex91.Rnw:491-493
###################################################
levels(cities$names)
levels(cities$names)[2] <- "Binghamton"


###################################################
### code chunk number 20: ex91.Rnw:503-511
###################################################
class(NY8)
plot(NY8, border="grey60", axes=TRUE, asp=1,
     main="Central New York census tracts")
class(cities)
points(cities, col="red")
text(coordinates(cities), labels=as.character(cities$names),
     font=2, cex=0.75, pos=4)
grid()


###################################################
### code chunk number 21: ex91.Rnw:529-531
###################################################
writeOGR(meuse.wgs84, dsn=".", layer="meuse84",
         driver="ESRI Shapefile", overwrite_layer=TRUE)


###################################################
### code chunk number 22: ex91.Rnw:567-568
###################################################
f <- system.file("external/test.ag", package="sp")[1]


###################################################
### code chunk number 23: ex91.Rnw:575-576 (eval = FALSE)
###################################################
## file.show(f)


###################################################
### code chunk number 24: ex91.Rnw:614-616
###################################################
test.grid <- read.asciigrid(f, colname="z")
str(test.grid)


###################################################
### code chunk number 25: ex91.Rnw:638-639
###################################################
image(test.grid, col=topo.colors(64))


###################################################
### code chunk number 26: ex91.Rnw:645-646 (eval = FALSE)
###################################################
## rm(f, test.grid)


###################################################
### code chunk number 27: ex91.Rnw:662-667
###################################################
data(volcano)
str(volcano)
dim(volcano)
filled.contour(volcano, color.palette = terrain.colors, asp = 1)
help(volcano)


###################################################
### code chunk number 28: ex91.Rnw:696-698
###################################################
volcano.sp <- data.frame(x = rep(1:dim(volcano)[1], dim(volcano)[2]), y=rep(1:dim(volcano)[2], each=dim(volcano)[1]), z=as.vector(volcano))
str(volcano.sp)


###################################################
### code chunk number 29: ex91.Rnw:703-705
###################################################
coordinates(volcano.sp) <- ~ x + y
str(volcano.sp)


###################################################
### code chunk number 30: ex91.Rnw:710-713
###################################################
gridded(volcano.sp) <- TRUE
str(volcano.sp)
print(spplot(volcano.sp, col.regions=terrain.colors(64), main="Maunga Whau (Mt Eden)"))


###################################################
### code chunk number 31: ex91.Rnw:722-723 (eval = FALSE)
###################################################
## rm(volcano, volcano.sp)


###################################################
### code chunk number 32: ex91.Rnw:760-761
###################################################
writeOGR(meuse.wgs84["zinc"], "meuseZnPoints.kml", "zinc", driver="KML", overwrite_layer=TRUE)


###################################################
### code chunk number 33: ex91.Rnw:805-873
###################################################
  ## setup: get the max. value, to normalize postplot symbol size
varname <- "zinc" # layer name
(maxvar <- max(meuse.wgs84@data[varname])) # maximum value
  ## open the KML file
filename <- file(paste(varname, "_bubble.kml", sep=""), "w") 
  ## header
write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>", filename) 
  ## begin KML
write("<kml xmlns=\"http://earth.google.com/kml/2.2\">",
      filename, append = TRUE) 
write("<Document>", filename, append = TRUE) 
write(paste("<name>", varname, "</name>", sep=" "),
      filename, append = TRUE) 
write("<open>1</open>", filename, append = TRUE)
  ## Write placemark symbols in a loop:
for (i in 1:length(meuse.wgs84@data[[1]])) { 
  write(paste(' <Style id="','pnt', i,'">',sep=""),
        filename, append = TRUE)
  write("	<LabelStyle>", filename, append = TRUE)
  write("	<scale>0.7</scale>", filename, append = TRUE)
  write("	</LabelStyle>", filename, append = TRUE)
  write("	<IconStyle>", filename, append = TRUE)
  write("	<color>ff0000ff</color>", filename, append = TRUE)
     ## postplot: scale by data value
  write(paste("	<scale>",
              meuse.wgs84[i,varname]@data[[1]]/maxvar*2+0.1,
              "</scale>", sep=""),
        filename, append = TRUE)
  write("	<Icon>", filename, append = TRUE)
     ## this is the icon to use -- here a donut
  write("	 <href>
http://maps.google.com/mapfiles/kml/shapes/donut.png</href>",
        filename, append = TRUE)
  write("	</Icon>", filename, append = TRUE)
  write("	</IconStyle>", filename, append = TRUE)
  write("	</Style>", filename, append = TRUE)
}
## placemark positions
write("<Folder>", filename, append = TRUE)
write(paste("<name>Donut icon for", varname,"</name>"),
      filename, append = TRUE)
  ## write placemark positions in a loop
for (i in 1:length(meuse.wgs84@data[[1]])) {
  write(" <Placemark>", filename, append = TRUE)
    ## the <name> will be displayed next to the symbol
  write(paste(" <name>", meuse.wgs84[i,varname]@data[[1]],
              "</name>", sep=""),
        filename, append = TRUE)
    ## this URL is a reference to the point stored above
    ##  in the <Style> list
  write(paste(" <styleUrl>#pnt",i,"</styleUrl>", sep=""),
        filename, append=TRUE)
    ## extract the placemark coordinates
  write("	<Point>", filename, append = TRUE)
  write(paste("	<coordinates>",
              coordinates(meuse.wgs84)[[i,1]],",",
              coordinates(meuse.wgs84)[[i,2]],
              ",10</coordinates>", sep=""), 
        filename,, append = TRUE)
  write("	</Point>", filename, append = TRUE)
  write("	</Placemark>", filename, append = TRUE)
}
write("</Folder>", filename, append = TRUE) 
  ## end KML
write("</Document>", filename, append = TRUE) 
write("</kml>", filename, append = TRUE)
  ## close the KML file
close(filename)


###################################################
### code chunk number 34: ex91.Rnw:903-906
###################################################
data(meuse.grid)
gridded(meuse.grid) = ~x+y
proj4string(meuse.grid) = proj4string(meuse)


###################################################
### code chunk number 35: ex91.Rnw:919-928
###################################################
v <- variogram(log(zinc) ~1, loc=meuse)
max(v$gamma)
which(v$gamma==max(v$gamma))
v[which(v$gamma==max(v$gamma)),"dist"]
(vm <- fit.variogram(v, model=vgm(max(v$gamma),
    "Sph", v[which(v$gamma==max(v$gamma)),"dist"]
    ,0)))
print(plot(v, pl=T, model=vm,
           main="Fitted varogram, log(Zn), Meuse soils"))


###################################################
### code chunk number 36: ex91.Rnw:943-945
###################################################
kr <- krige(log(zinc) ~ 1, loc=meuse, newdata=meuse.grid, model=vm)
print(spplot(kr, zcol="var1.pred", col.regions=heat.colors(64), main="Meuse topsoils, Log-ppm zinc" ))


###################################################
### code chunk number 37: ex91.Rnw:956-961
###################################################
class(kr)
head(coordinates(kr))
kr.wgs84 <- spTransform(kr, CRS("+proj=longlat +datum=WGS84"))
class(kr.wgs84)
head(coordinates(kr.wgs84))


###################################################
### code chunk number 38: ex91.Rnw:984-985
###################################################
kr@grid@cells.dim


###################################################
### code chunk number 39: ex91.Rnw:1016-1027
###################################################
require(rgeos)
class(meuse.grid)
length(meuse.grid@coords[,"x"])
grd <- as(meuse.grid, "SpatialPolygons") 
class(grd)
length(grd@polygons)
# gpclibPermit()
grd.union <- unionSpatialPolygons(grd, rep("x", length(grd@polygons))) 
class(grd.union)
length(grd.union@polygons)
plot(grd.union, main="Bounding polygon, Meuse interpolation grid")


###################################################
### code chunk number 40: export-grd (eval = FALSE)
###################################################
## tmp.df <- data.frame(x=1, row.names="x")
## grd.union.df <- SpatialPolygonsDataFrame(grd.union, data=tmp.df)
## writeOGR(grd.union.df, dsn=".", layer="meuseBoundary", driver="ESRI Shapefile")
## rm(tmp.df, grd.union.df)


###################################################
### code chunk number 41: export-grd-hide
###################################################
tmp.df <- data.frame(x=1, row.names="x")
grd.union.df <- SpatialPolygonsDataFrame(grd.union, data=tmp.df)
writeOGR(grd.union.df, "./ds/meuse", "meuseBoundary", driver="ESRI Shapefile", overwrite_layer=TRUE)


###################################################
### code chunk number 42: ex91.Rnw:1074-1078
###################################################
bbox(grd.union)
grd.union.wgs84 <- spTransform(grd.union,
                               CRS("+proj=longlat +datum=WGS84"))
bbox(grd.union.wgs84)


###################################################
### code chunk number 43: ex91.Rnw:1089-1091
###################################################
GRD.wgs84 <- GE_SpatialGrid(grd.union.wgs84, maxPixels=2*max(kr@grid@cells.dim))
str(GRD.wgs84)


###################################################
### code chunk number 44: ex91.Rnw:1096-1097
###################################################
GRD.wgs84$asp


###################################################
### code chunk number 45: ex91.Rnw:1109-1110
###################################################
str(GRD.wgs84)


###################################################
### code chunk number 46: ex91.Rnw:1117-1120
###################################################
GRD.wgs84_in <- over(GRD.wgs84$SG, grd.union.wgs84)
str(GRD.wgs84_in)
unique(GRD.wgs84_in)


###################################################
### code chunk number 47: ex91.Rnw:1132-1139
###################################################
llSGDF <- SpatialGridDataFrame(grid = GRD.wgs84$SG@grid,
                               proj4string = 
                               CRS(proj4string(GRD.wgs84$SG)),
                               data = 
                               data.frame(pred = GRD.wgs84_in)) 
llSPix <- as(llSGDF, "SpatialPixelsDataFrame")
print(spplot(llSPix, zcol="pred", col.regions="lightblue"))


###################################################
### code chunk number 48: ex91.Rnw:1159-1161
###################################################
(st <- system.time(llSPix$pred <- idw(var1.pred ~ 1, loc=kr.wgs84, newdata=llSPix, nmax=8)$var1.pred))
summary(llSPix)


###################################################
### code chunk number 49: ex91.Rnw:1171-1172
###################################################
image(llSPix, "pred", col = bpy.colors(20))


###################################################
### code chunk number 50: ex91.Rnw:1178-1182
###################################################
png(file="MeuseZnInterpolation.png", width=GRD.wgs84$width, height=GRD.wgs84$height, bg="transparent")
par(mar = c(0, 0, 0, 0), xaxs = "i", yaxs = "i") 
image(llSPix, "pred", col=bpy.colors(128))
dev.off()


###################################################
### code chunk number 51: ex91.Rnw:1196-1200 (eval = FALSE)
###################################################
## image(
##     matrix(llSPix$pred,
##       nrow=GRD.wgs84$SG@grid@cells.dim[1],
##       ncol=GRD.wgs84$SG@grid@cells.dim[2]))


###################################################
### code chunk number 52: ex91.Rnw:1207-1210
###################################################
kmlOverlay(obj=GRD.wgs84, kmlfile="MeuseZn.kml",
           imagefile="MeuseZn.png",
           name="Log(Zn) concentration, Meuse soils") 


###################################################
### code chunk number 53: ex91.Rnw:1215-1216
###################################################
file.show("MeuseZn.kml")


###################################################
### code chunk number 54: ex91.Rnw:1252-1253 (eval = FALSE)
###################################################
## rm(meuse, meuse.wgs84, meuse.grid, v, vm, v.rd, v.wgs84, GRD.wgs84, GRD.wgs84_in, llSGDF, llSPix, grd, grd.union, grd.union.wgs84, kr, kr.wgs84, st)


###################################################
### code chunk number 55: ex91.Rnw:1343-1346
###################################################
rm(meuse, meuse.wgs84, meuse.grid, v, vm, v.rd, v.wgs84, GRD.wgs84, GRD.wgs84_in, llSGDF, llSPix, grd, grd.union, grd.union.wgs84, kr, kr.wgs84, st)
rm(f, test.grid)
rm(volcano, volcano.sp)


